@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -48,13 +48,12 @@ class CControllerPopupHttpStep extends CController {
 		$ret = $this->validateInput($fields);
 
 		if (!$ret) {
-			$output = [];
-			if (($messages = getMessages()) !== null) {
-				$output['errors'] = $messages->toString();
-			}
-
 			$this->setResponse(
-				(new CControllerResponseData(['main_block' => CJs::encodeJson($output)]))->disableView()
+				(new CControllerResponseData(['main_block' => json_encode([
+					'error' => [
+						'messages' => array_column(get_and_clear_messages(), 'message')
+					]
+				])]))->disableView()
 			);
 		}
 
@@ -96,7 +95,7 @@ class CControllerPopupHttpStep extends CController {
 			elseif ($page_options['timeout'][0] !== '{') {
 				$seconds = timeUnitToSeconds($page_options['timeout']);
 
-				if ($seconds < 1 || bccomp($seconds, SEC_PER_HOUR) > 0) {
+				if ($seconds < 1 || $seconds > SEC_PER_HOUR) {
 					error(_s('Invalid parameter "%1$s": %2$s.', 'timeout',
 						_s('value must be one of %1$s', '1-'.SEC_PER_HOUR)
 					));
@@ -113,8 +112,8 @@ class CControllerPopupHttpStep extends CController {
 			}
 
 			// Return collected error messages.
-			if (($messages = getMessages()) !== null) {
-				$output['errors'] = $messages->toString();
+			if ($messages = get_and_clear_messages()) {
+				$output['error']['messages'] = array_column($messages, 'message');
 			}
 			else {
 				// Return valid response.
@@ -137,7 +136,7 @@ class CControllerPopupHttpStep extends CController {
 			}
 
 			$this->setResponse(
-				(new CControllerResponseData(['main_block' => CJs::encodeJson($output)]))->disableView()
+				(new CControllerResponseData(['main_block' => json_encode($output)]))->disableView()
 			);
 		}
 		else {
