@@ -1,7 +1,7 @@
-<?php declare(strict_types = 1);
+<?php declare(strict_types = 0);
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -23,9 +23,9 @@ require_once dirname(__FILE__).'/../../include/forms.inc.php';
 
 class CControllerPopupMassupdateHost extends CControllerPopupMassupdateAbstract {
 
-	protected function checkInput() {
+	protected function checkInput(): bool {
 		$fields = [
-			'ids' => 'required|array',
+			'hostids' => 'required|array',
 			'update' => 'in 1',
 			'visible' => 'array',
 			'tags' => 'array',
@@ -64,67 +64,78 @@ class CControllerPopupMassupdateHost extends CControllerPopupMassupdateAbstract
 			'tls_connect' => 'in '.implode(',', [HOST_ENCRYPTION_NONE, HOST_ENCRYPTION_PSK, HOST_ENCRYPTION_CERTIFICATE]),
 			'tls_accept' => 'ge 0|le '.(HOST_ENCRYPTION_NONE | HOST_ENCRYPTION_PSK | HOST_ENCRYPTION_CERTIFICATE),
 			'ipmi_authtype' => 'in '.implode(',', [IPMI_AUTHTYPE_DEFAULT, IPMI_AUTHTYPE_NONE, IPMI_AUTHTYPE_MD2, IPMI_AUTHTYPE_MD5, IPMI_AUTHTYPE_STRAIGHT, IPMI_AUTHTYPE_OEM, IPMI_AUTHTYPE_RMCP_PLUS]),
-			'ipmi_privilege' => 'in '.implode(',', [IPMI_PRIVILEGE_CALLBACK, IPMI_PRIVILEGE_USER, IPMI_PRIVILEGE_OPERATOR, IPMI_PRIVILEGE_ADMIN, IPMI_PRIVILEGE_OEM])
+			'ipmi_privilege' => 'in '.implode(',', [IPMI_PRIVILEGE_CALLBACK, IPMI_PRIVILEGE_USER, IPMI_PRIVILEGE_OPERATOR, IPMI_PRIVILEGE_ADMIN, IPMI_PRIVILEGE_OEM]),
+			'backurl' => 'string'
 		];
 
 		$ret = $this->validateInput($fields);
 
-		if (!$ret) {
-			$output = [];
-			if (($messages = getMessages()) !== null) {
-				$output['errors'] = $messages->toString();
+		if ($ret && $this->hasInput('tags')) {
+			foreach ($this->getInput('tags') as $tag) {
+				if (!is_array($tag) || count($tag) != 2
+						|| !array_key_exists('tag', $tag) || !is_string($tag['tag'])
+						|| !array_key_exists('value', $tag) || !is_string($tag['value'])) {
+					error(_s('Incorrect value for "%1$s" field.', 'tags'));
+					$ret = false;
+					break;
+				}
 			}
+		}
 
+		if (!$ret) {
 			$this->setResponse(
-				(new CControllerResponseData(['main_block' => json_encode($output)]))->disableView()
+				(new CControllerResponseData(['main_block' => json_encode([
+					'error' => [
+						'messages' => array_column(get_and_clear_messages(), 'message')
+					]
+				])]))->disableView()
 			);
 		}
 
 		return $ret;
 	}
 
-	protected function checkPermissions() {
+	protected function checkPermissions(): bool {
 		$hosts = API::Host()->get([
 			'output' => [],
-			'hostids' => $this->getInput('ids'),
+			'hostids' => $this->getInput('hostids'),
 			'editable' => true
 		]);
 
 		return count($hosts) > 0;
 	}
 
-	protected function doAction() {
+	protected function doAction(): void {
 		if ($this->hasInput('update')) {
-			$output = [];
-			$hostids = $this->getInput('ids');
+			$hostids = $this->getInput('hostids');
 			$visible = $this->getInput('visible', []);
+
 			$macros = array_filter(cleanInheritedMacros($this->getInput('macros', [])),
-				function (array $macro): bool {
+				static function (array $macro): bool {
 					return (bool) array_filter(
 						array_intersect_key($macro, array_flip(['hostmacroid', 'macro', 'value', 'description']))
 					);
 				}
 			);
+
 			$tags = array_filter($this->getInput('tags', []),
-				function (array $tag): bool {
-					return ($tag['tag'] !== '' || $tag['value'] !== '');
+				static function (array $tag): bool {
+					return $tag['tag'] !== '' || $tag['value'] !== '';
 				}
 			);
 
-			$result = true;
-
 			try {
 				DBstart();
 
 				// filter only normal and discovery created hosts
 				$options = [
-					'output' => ['hostid', 'inventory_mode', 'flags'],
+					'output' => ['hostid', 'host', 'inventory_mode', 'flags'],
 					'hostids' => $hostids,
 					'filter' => ['flags' => [ZBX_FLAG_DISCOVERY_NORMAL, ZBX_FLAG_DISCOVERY_CREATED]]
 				];
 
 				if (array_key_exists('groups', $visible)) {
-					$options['selectGroups'] = ['groupid'];
+					$options['selectHostGroups'] = ['groupid'];
 				}
 
 				if (array_key_exists('templates', $visible)
@@ -134,19 +145,7 @@ class CControllerPopupMassupdateHost extends CControllerPopupMassupdateAbstract
 				}
 
 				if (array_key_exists('tags', $visible)) {
-					$mass_update_tags = $this->getInput('mass_update_tags', ZBX_ACTION_ADD);
-
-					if ($mass_update_tags == ZBX_ACTION_ADD || $mass_update_tags == ZBX_ACTION_REMOVE) {
-						$options['selectTags'] = ['tag', 'value'];
-					}
-
-					$unique_tags = [];
-
-					foreach ($tags as $tag) {
-						$unique_tags[$tag['tag'].':'.$tag['value']] = $tag;
-					}
-
-					$tags = array_values($unique_tags);
+					$options['selectTags'] = ['tag', 'value', 'automatic'];
 				}
 
 				if (array_key_exists('macros', $visible)) {
@@ -237,13 +236,10 @@ class CControllerPopupMassupdateHost extends CControllerPopupMassupdateAbstract
 					}
 				}
 
-				$host_macros_add = [];
-				$host_macros_update = [];
-				$host_macros_remove = [];
 				foreach ($hosts as &$host) {
 					if (array_key_exists('groups', $visible)) {
 						if ($new_groupids && $mass_update_groups == ZBX_ACTION_ADD) {
-							$current_groupids = array_column($host['groups'], 'groupid');
+							$current_groupids = array_column($host['hostgroups'], 'groupid');
 							$host['groups'] = zbx_toObject(array_unique(array_merge($current_groupids, $new_groupids)),
 								'groupid'
 							);
@@ -252,9 +248,10 @@ class CControllerPopupMassupdateHost extends CControllerPopupMassupdateAbstract
 							$host['groups'] = zbx_toObject($new_groupids, 'groupid');
 						}
 						elseif ($remove_groupids) {
-							$current_groupids = array_column($host['groups'], 'groupid');
+							$current_groupids = array_column($host['hostgroups'], 'groupid');
 							$host['groups'] = zbx_toObject(array_diff($current_groupids, $remove_groupids), 'groupid');
 						}
+						unset($host['hostgroups']);
 					}
 
 					if (array_key_exists('templates', $visible)) {
@@ -264,26 +261,30 @@ class CControllerPopupMassupdateHost extends CControllerPopupMassupdateAbstract
 
 						switch ($this->getInput('mass_action_tpls')) {
 							case ZBX_ACTION_ADD:
-								$host['templates'] = array_unique(
-									array_merge($host_templateids, $this->getInput('templates', []))
+								$host['templates'] = zbx_toObject(
+									array_unique(array_merge($host_templateids, $this->getInput('templates', []))),
+									'templateid'
 								);
 								break;
 
 							case ZBX_ACTION_REPLACE:
-								$host['templates'] = $this->getInput('templates', []);
+								$host['templates'] = zbx_toObject($this->getInput('templates', []), 'templateid');
+
 								if ($this->hasInput('mass_clear_tpls')) {
-									$host['templates_clear'] = array_unique(
-										array_diff($host_templateids, $this->getInput('templates', []))
+									$host['templates_clear'] = zbx_toObject(
+										array_diff($host_templateids, $this->getInput('templates', [])), 'templateid'
 									);
 								}
 								break;
 
 							case ZBX_ACTION_REMOVE:
-								$host['templates'] = array_unique(
-									array_diff($host_templateids, $this->getInput('templates', []))
+								$host['templates'] = zbx_toObject(
+									array_diff($host_templateids, $this->getInput('templates', [])), 'templateid'
 								);
+
 								if ($this->hasInput('mass_clear_tpls')) {
-									$host['templates_clear'] = array_unique($this->getInput('templates', []));
+									$host['templates_clear'] =
+										zbx_toObject($this->getInput('templates', []), 'templateid');
 								}
 								break;
 						}
@@ -305,77 +306,116 @@ class CControllerPopupMassupdateHost extends CControllerPopupMassupdateAbstract
 					}
 
 					if (array_key_exists('tags', $visible)) {
-						if ($tags && $mass_update_tags == ZBX_ACTION_ADD) {
-							$unique_tags = [];
+						switch ($this->getInput('mass_update_tags', ZBX_ACTION_ADD)) {
+							case ZBX_ACTION_ADD:
+								$tags_map = [];
 
-							foreach (array_merge($host['tags'], $tags) as $tag) {
-								$unique_tags[$tag['tag'].':'.$tag['value']] = $tag;
-							}
-
-							$host['tags'] = array_values($unique_tags);
-						}
-						elseif ($mass_update_tags == ZBX_ACTION_REPLACE) {
-							$host['tags'] = $tags;
-						}
-						elseif ($tags && $mass_update_tags == ZBX_ACTION_REMOVE) {
-							$diff_tags = [];
-
-							foreach ($host['tags'] as $a) {
-								foreach ($tags as $b) {
-									if ($a['tag'] === $b['tag'] && $a['value'] === $b['value']) {
-										continue 2;
-									}
+								foreach ($host['tags'] as $tag) {
+									unset($tag['automatic']);
+									$tags_map[$tag['tag']][$tag['value']] = $tag;
 								}
 
-								$diff_tags[] = $a;
-							}
+								foreach ($tags as $tag) {
+									$tags_map[$tag['tag']][$tag['value']] = $tag;
+								}
 
-							$host['tags'] = $diff_tags;
+								$host['tags'] = [];
+
+								foreach ($tags_map as $tags_map_2) {
+									foreach ($tags_map_2 as $tag) {
+										$host['tags'][] = $tag;
+									}
+								}
+								break;
+
+							case ZBX_ACTION_REPLACE:
+								$tags_map = [];
+
+								foreach ($tags as $tag) {
+									$tags_map[$tag['tag']][$tag['value']] = $tag;
+								}
+
+								$host['tags'] = [];
+
+								foreach ($tags_map as $tags_map_2) {
+									foreach ($tags_map_2 as $tag) {
+										$host['tags'][] = $tag;
+									}
+								}
+								break;
+
+							case ZBX_ACTION_REMOVE:
+								$tags_map = [];
+
+								foreach ($host['tags'] as $tag) {
+									$tags_map[$tag['tag']][$tag['value']] = $tag;
+								}
+
+								foreach ($tags as $tag) {
+									if (!array_key_exists($tag['tag'], $tags_map)
+											|| !array_key_exists($tag['value'], $tags_map[$tag['tag']])) {
+										continue;
+									}
+
+									if ($tags_map[$tag['tag']][$tag['value']]['automatic'] == ZBX_TAG_AUTOMATIC) {
+										error(_s(
+											'Cannot remove the tag with name "%1$s" and value "%2$s", defined in a host prototype, from host "%3$s".',
+											$tag['tag'], $tag['value'], $host['host']
+										));
+										throw new Exception();
+									}
+
+									unset($tags_map[$tag['tag']][$tag['value']]);
+								}
+
+								$host['tags'] = [];
+
+								foreach ($tags_map as $tags_map_2) {
+									foreach ($tags_map_2 as $tag) {
+										unset($tag['automatic']);
+										$host['tags'][] = $tag;
+									}
+								}
+								break;
 						}
 					}
 
 					if (array_key_exists('macros', $visible)) {
 						switch ($mass_update_macros) {
 							case ZBX_ACTION_ADD:
-								if ($macros) {
-									$update_existing = $this->getInput('macros_add', 0);
+								$update_existing = (bool) getRequest('macros_add', 0);
+								$host['macros'] = array_column($host['macros'], null, 'hostmacroid');
+								$host_macros_by_macro = array_column($host['macros'], null, 'macro');
 
-									foreach ($macros as $macro) {
-										foreach ($host['macros'] as $host_macro) {
-											if ($macro['macro'] === $host_macro['macro']) {
-												if ($update_existing) {
-													$macro['hostmacroid'] = $host_macro['hostmacroid'];
-													$host_macros_update[] = $macro;
-												}
-
-												continue 2;
-											}
-										}
-
-										$macro['hostid'] = $host['hostid'];
-										$host_macros_add[] = $macro;
+								foreach ($macros as $macro) {
+									if (!array_key_exists($macro['macro'], $host_macros_by_macro)) {
+										$host['macros'][] = $macro;
+									}
+									elseif ($update_existing) {
+										$hostmacroid = $host_macros_by_macro[$macro['macro']]['hostmacroid'];
+										$host['macros'][$hostmacroid] = [
+											'hostmacroid' => $hostmacroid,
+											'automatic' => ZBX_USERMACRO_MANUAL
+										] + $macro;
 									}
 								}
 								break;
 
-							case ZBX_ACTION_REPLACE: // In Macros its update.
-								if ($macros) {
-									$add_missing = $this->getInput('macros_update', 0);
+							case ZBX_ACTION_REPLACE:
+								$add_missing = (bool) getRequest('macros_update', 0);
+								$host['macros'] = array_column($host['macros'], null, 'hostmacroid');
+								$host_macros_by_macro = array_column($host['macros'], null, 'macro');
 
-									foreach ($macros as $macro) {
-										foreach ($host['macros'] as $host_macro) {
-											if ($macro['macro'] === $host_macro['macro']) {
-												$macro['hostmacroid'] = $host_macro['hostmacroid'];
-												$host_macros_update[] = $macro;
-
-												continue 2;
-											}
-										}
-
-										if ($add_missing) {
-											$macro['hostid'] = $host['hostid'];
-											$host_macros_add[] = $macro;
-										}
+								foreach ($macros as $macro) {
+									if (array_key_exists($macro['macro'], $host_macros_by_macro)) {
+										$hostmacroid = $host_macros_by_macro[$macro['macro']]['hostmacroid'];
+										$host['macros'][$hostmacroid] = [
+											'hostmacroid' => $hostmacroid,
+											'automatic' => ZBX_USERMACRO_MANUAL
+										] + $macro;
+									}
+									elseif ($add_missing) {
+										$host['macros'][] = $macro;
 									}
 								}
 								break;
@@ -383,15 +423,12 @@ class CControllerPopupMassupdateHost extends CControllerPopupMassupdateAbstract
 							case ZBX_ACTION_REMOVE:
 								if ($macros) {
 									$except_selected = $this->getInput('macros_remove', 0);
+									$host_macros_by_macro = array_column($host['macros'], null, 'macro');
+									$macros_by_macro = array_column($macros, null, 'macro');
 
-									$macro_names = array_column($macros, 'macro');
-
-									foreach ($host['macros'] as $host_macro) {
-										if ((!$except_selected && in_array($host_macro['macro'], $macro_names))
-												|| ($except_selected && !in_array($host_macro['macro'], $macro_names))) {
-											$host_macros_remove[] = $host_macro['hostmacroid'];
-										}
-									}
+									$host['macros'] = $except_selected
+										? array_intersect_key($host_macros_by_macro, $macros_by_macro)
+										: array_diff_key($host_macros_by_macro, $macros_by_macro);
 								}
 								break;
 
@@ -404,9 +441,7 @@ class CControllerPopupMassupdateHost extends CControllerPopupMassupdateAbstract
 								break;
 						}
 
-						if ($mass_update_macros != ZBX_ACTION_REMOVE_ALL) {
-							unset($host['macros']);
-						}
+						$host['macros'] = array_values($host['macros']);
 					}
 
 					unset($host['parentTemplates']);
@@ -420,7 +455,7 @@ class CControllerPopupMassupdateHost extends CControllerPopupMassupdateAbstract
 					if ($host['flags'] == ZBX_FLAG_DISCOVERY_CREATED) {
 						unset($host['inventory_mode']);
 					}
-					unset($host['flags']);
+					unset($host['host'], $host['flags']);
 				}
 				unset($host);
 
@@ -430,28 +465,6 @@ class CControllerPopupMassupdateHost extends CControllerPopupMassupdateAbstract
 					throw new Exception();
 				}
 
-				/**
-				 * Macros must be updated separately, since calling API::UserMacro->replaceMacros() inside
-				 * API::Host->update() results in loss of secret macro values.
-				 */
-				if ($host_macros_remove) {
-					if (!API::UserMacro()->delete($host_macros_remove)) {
-						throw new Exception();
-					}
-				}
-
-				if ($host_macros_add) {
-					if (!API::UserMacro()->create($host_macros_add)) {
-						throw new Exception();
-					}
-				}
-
-				if ($host_macros_update) {
-					if (!API::UserMacro()->update($host_macros_update)) {
-						throw new Exception();
-					}
-				}
-
 				// Value mapping.
 				if (array_key_exists('valuemaps', $visible)) {
 					$this->updateValueMaps($hostids);
@@ -462,25 +475,55 @@ class CControllerPopupMassupdateHost extends CControllerPopupMassupdateAbstract
 			catch (Exception $e) {
 				DBend(false);
 
-				CMessageHelper::setErrorTitle(_('Cannot update hosts'));
-
 				$result = false;
 			}
 
-			if ($result) {
-				$messages = CMessageHelper::getMessages();
-				$output = ['title' => _('Hosts updated')];
-				if (count($messages)) {
-					$output['messages'] = array_column($messages, 'message');
+			if ($this->hasInput('backurl')) {
+				$upd_status = ($this->getInput('status', HOST_STATUS_NOT_MONITORED) == HOST_STATUS_MONITORED);
+				$backurl = new CUrl($this->getInput('backurl'));
+				$cnt = count($hostids);
+
+				if ($result) {
+					$backurl->setArgument('uncheck', 1);
+
+					CMessageHelper::setSuccessTitle($upd_status
+						? _n('Host enabled', 'Hosts enabled', $cnt)
+						: _n('Host disabled', 'Hosts disabled', $cnt)
+					);
 				}
+				else {
+					CMessageHelper::setErrorTitle($upd_status
+						? _n('Cannot enable host', 'Cannot enable hosts', $cnt)
+						: _n('Cannot disable host', 'Cannot disable hosts', $cnt)
+					);
+				}
+
+				$this->setResponse(new CControllerResponseRedirect($backurl->getUrl()));
 			}
 			else {
-				$output['errors'] = makeMessageBox(false, filter_messages(), CMessageHelper::getTitle())->toString();
-			}
+				if ($result) {
+					ob_start();
+					uncheckTableRows('hosts');
 
-			$this->setResponse(
-				(new CControllerResponseData(['main_block' => json_encode($output)]))->disableView()
-			);
+					$output = ['title' => _('Hosts updated'), 'script_inline' => ob_get_clean()];
+
+					if ($messages = CMessageHelper::getMessages()) {
+						$output['messages'] = array_column($messages, 'message');
+					}
+				}
+				else {
+					$output = [
+						'error' => [
+							'title' => _('Cannot update hosts'),
+							'messages' => array_column(get_and_clear_messages(), 'message')
+						]
+					];
+				}
+
+				$this->setResponse(
+					(new CControllerResponseData(['main_block' => json_encode($output)]))->disableView()
+				);
+			}
 		}
 		else {
 			$data = [
@@ -488,9 +531,12 @@ class CControllerPopupMassupdateHost extends CControllerPopupMassupdateAbstract
 				'user' => [
 					'debug_mode' => $this->getDebugMode()
 				],
-				'ids' => $this->getInput('ids'),
+				'hostids' => $this->getInput('hostids'),
 				'inventories' => zbx_toHash(getHostInventories(), 'db_field'),
-				'location_url' => 'hosts.php'
+				'location_url' => (new CUrl('zabbix.php'))
+					->setArgument('action', 'host.list')
+					->setArgument('page', CPagerHelper::loadPage('host.list'))
+					->getUrl()
 			];
 
 			$data['proxies'] = API::Proxy()->get([
@@ -503,7 +549,7 @@ class CControllerPopupMassupdateHost extends CControllerPopupMassupdateAbstract
 
 			$data['discovered_host'] = !(bool) API::Host()->get([
 				'output' => [],
-				'hostids' => $data['ids'],
+				'hostids' => $data['hostids'],
 				'filter' => ['flags' => ZBX_FLAG_DISCOVERY_NORMAL],
 				'limit' => 1
 			]);
