@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -64,7 +64,7 @@ class CControllerUserEdit extends CControllerUserEditGeneral {
 		return $ret;
 	}
 
-	protected function checkPermissions() {
+	protected function checkPermissions(): bool {
 		if (!$this->checkAccess(CRoleHelper::UI_ADMINISTRATION_USERS)) {
 			return false;
 		}
@@ -76,7 +76,6 @@ class CControllerUserEdit extends CControllerUserEditGeneral {
 				],
 				'selectMedias' => ['mediatypeid', 'period', 'sendto', 'severity', 'active'],
 				'selectUsrgrps' => ['usrgrpid'],
-				'selectRole' => ['name', 'type'],
 				'userids' => $this->getInput('userid'),
 				'editable' => true
 			]);
@@ -91,7 +90,7 @@ class CControllerUserEdit extends CControllerUserEditGeneral {
 		return true;
 	}
 
-	protected function doAction() {
+	protected function doAction(): void {
 		$db_defaults = DB::getDefaults('users');
 
 		$data = [
@@ -144,8 +143,6 @@ class CControllerUserEdit extends CControllerUserEditGeneral {
 
 			if (!$this->getInput('form_refresh', 0)) {
 				$data['roleid'] = $this->user['roleid'];
-				$data['user_type'] = $this->user['role']['type'];
-				$data['role'] = [['id' => $data['roleid'], 'name' => $this->user['role']['name']]];
 			}
 		}
 		else {
@@ -162,6 +159,7 @@ class CControllerUserEdit extends CControllerUserEditGeneral {
 			$data['medias'] = $this->getInput('medias', []);
 		}
 
+		$data['password_requirements'] = $this->getPasswordRequirements();
 		$data = $this->setUserMedias($data);
 
 		$data['groups'] = $user_groups
@@ -173,15 +171,52 @@ class CControllerUserEdit extends CControllerUserEditGeneral {
 		CArrayHelper::sort($data['groups'], ['name']);
 		$data['groups'] = CArrayHelper::renameObjectsKeys($data['groups'], ['usrgrpid' => 'id']);
 
-		if ($data['form_refresh'] && $this->hasInput('roleid')) {
+		if ($data['roleid']) {
 			$roles = API::Role()->get([
 				'output' => ['name', 'type'],
+				'selectRules' => ['services.read.mode', 'services.read.list', 'services.read.tag',
+					'services.write.mode', 'services.write.list', 'services.write.tag'
+				],
 				'roleids' => $data['roleid']
 			]);
 
 			if ($roles) {
-				$data['role'] = [['id' => $data['roleid'], 'name' => $roles[0]['name']]];
-				$data['user_type'] = $roles[0]['type'];
+				$role = $roles[0];
+
+				$data['role'] = [['id' => $data['roleid'], 'name' => $role['name']]];
+				$data['user_type'] = $role['type'];
+
+				if ($role['rules']['services.read.mode'] == ZBX_ROLE_RULE_SERVICES_ACCESS_ALL) {
+					$data['service_read_access'] = CRoleHelper::SERVICES_ACCESS_ALL;
+				}
+				elseif ($role['rules']['services.read.list'] || $role['rules']['services.read.tag']['tag'] !== '') {
+					$data['service_read_access'] = CRoleHelper::SERVICES_ACCESS_LIST;
+				}
+				else {
+					$data['service_read_access'] = CRoleHelper::SERVICES_ACCESS_NONE;
+				}
+
+				$data['service_read_list'] = API::Service()->get([
+					'output' => ['serviceid', 'name'],
+					'serviceids' => array_column($role['rules']['services.read.list'], 'serviceid')
+				]);
+				$data['service_read_tag'] = $role['rules']['services.read.tag'];
+
+				if ($role['rules']['services.write.mode'] == ZBX_ROLE_RULE_SERVICES_ACCESS_ALL) {
+					$data['service_write_access'] = CRoleHelper::SERVICES_ACCESS_ALL;
+				}
+				elseif ($role['rules']['services.write.list'] || $role['rules']['services.write.tag']['tag'] !== '') {
+					$data['service_write_access'] = CRoleHelper::SERVICES_ACCESS_LIST;
+				}
+				else {
+					$data['service_write_access'] = CRoleHelper::SERVICES_ACCESS_NONE;
+				}
+
+				$data['service_write_list'] = API::Service()->get([
+					'output' => ['serviceid', 'name'],
+					'serviceids' => array_column($role['rules']['services.write.list'], 'serviceid')
+				]);
+				$data['service_write_tag'] = $role['rules']['services.write.tag'];
 			}
 		}
 
@@ -193,9 +228,17 @@ class CControllerUserEdit extends CControllerUserEditGeneral {
 					'grouped' => '1'
 				]
 			];
+			$data['templategroups_rights'] = [
+				'0' => [
+					'permission' => PERM_READ_WRITE,
+					'name' => '',
+					'grouped' => '1'
+				]
+			];
 		}
 		else {
-			$data['groups_rights'] = collapseHostGroupRights(getHostGroupsRights($user_groups));
+			$data['groups_rights'] = collapseGroupRights(getHostGroupsRights($user_groups));
+			$data['templategroups_rights'] = collapseGroupRights(getTemplateGroupsRights($user_groups));
 		}
 
 		$data['modules'] = API::Module()->get([
