@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -71,7 +71,7 @@ $widget = (new CWidget())
 			(new CFormList())->addRow(_('Last name'),
 				(new CTextBox('filter_surname', $data['filter']['surname']))->setWidth(ZBX_TEXTAREA_FILTER_SMALL_WIDTH)
 			),
-			(new CFormList())->addRow((new CLabel(_('User roles'), 'filter_roles')),
+			(new CFormList())->addRow((new CLabel(_('User roles'), 'filter_roles__ms')),
 				(new CMultiSelect([
 					'name' => 'filter_roles[]',
 					'object_name' => 'roles',
