@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -29,14 +29,17 @@ if ($data['uncheck']) {
 
 $widget = (new CWidget())
 	->setTitle(_('User groups'))
-	->setControls((new CTag('nav', true,
-		(new CList())
-			->addItem(new CRedirectButton(_('Create user group'),
-				(new CUrl('zabbix.php'))->setArgument('action', 'usergroup.edit'))
-			)
+	->setDocUrl(CDocHelper::getUrl(CDocHelper::ADMINISTRATION_USERGROUP_LIST))
+	->setControls(
+		(new CTag('nav', true,
+			(new CList())
+				->addItem(new CRedirectButton(_('Create user group'),
+					(new CUrl('zabbix.php'))->setArgument('action', 'usergroup.edit')
+				))
 		))->setAttribute('aria-label', _('Content controls'))
 	)
-	->addItem((new CFilter((new CUrl('zabbix.php'))->setArgument('action', 'usergroup.list')))
+	->addItem((new CFilter())
+		->setResetUrl((new CUrl('zabbix.php'))->setArgument('action', 'usergroup.list'))
 		->addVar('action', 'usergroup.list')
 		->setProfile($data['profileIdx'])
 		->setActiveTab($data['active_tab'])
