@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 
 /**
  * @var CView $this
+ * @var array $data
  */
 
 if (array_key_exists('error', $data)) {
@@ -31,14 +32,19 @@ if (array_key_exists('error', $data)) {
 
 $this->addJsFile('flickerfreescreen.js');
 $this->addJsFile('gtlc.js');
+$this->addJsFile('leaflet.js');
+$this->addJsFile('leaflet.markercluster.js');
 $this->addJsFile('class.dashboard.js');
 $this->addJsFile('class.dashboard.page.js');
 $this->addJsFile('class.dashboard.widget.placeholder.js');
+$this->addJsFile('class.geomaps.js');
 $this->addJsFile('class.widget.js');
 $this->addJsFile('class.widget.iterator.js');
 $this->addJsFile('class.widget.clock.js');
+$this->addJsFile('class.widget.geomap.js');
 $this->addJsFile('class.widget.graph.js');
 $this->addJsFile('class.widget.graph-prototype.js');
+$this->addJsFile('class.widget.item.js');
 $this->addJsFile('class.widget.map.js');
 $this->addJsFile('class.widget.navtree.js');
 $this->addJsFile('class.widget.paste-placeholder.js');
@@ -47,22 +53,21 @@ $this->addJsFile('class.widget.problemsbysv.js');
 $this->addJsFile('class.widget.svggraph.js');
 $this->addJsFile('class.widget.trigerover.js');
 $this->addJsFile('class.calendar.js');
-$this->addJsFile('multiselect.js');
 $this->addJsFile('layout.mode.js');
 $this->addJsFile('class.coverride.js');
-$this->addJsFile('class.cverticalaccordion.js');
 $this->addJsFile('class.crangecontrol.js');
 $this->addJsFile('colorpicker.js');
 $this->addJsFile('class.csvggraph.js');
 $this->addJsFile('class.cnavtree.js');
 $this->addJsFile('class.svg.canvas.js');
 $this->addJsFile('class.svg.map.js');
-$this->addJsFile('class.tab-indicators.js');
 $this->addJsFile('class.tagfilteritem.js');
 $this->addJsFile('class.sortable.js');
 
 $this->includeJsFile('monitoring.dashboard.view.js.php');
 
+$this->addCssFile('assets/styles/vendors/Leaflet/Leaflet/leaflet.css');
+
 $this->enableLayoutModes();
 $web_layout_mode = $this->getLayoutMode();
 
@@ -98,6 +103,7 @@ if ($data['dynamic']['has_dynamic_widgets']) {
 $widget = (new CWidget())
 	->setTitle($data['dashboard']['name'])
 	->setWebLayoutMode($web_layout_mode)
+	->setDocUrl(CDocHelper::getUrl(CDocHelper::MONITORING_DASHBOARD_VIEW))
 	->setControls(
 		(new CList())
 			->setId('dashboard-control')
@@ -192,7 +198,7 @@ $widget = (new CWidget())
 
 if ($data['has_time_selector']) {
 	$widget->addItem(
-		(new CFilter(new CUrl()))
+		(new CFilter())
 			->setProfile($data['time_period']['profileIdx'], $data['time_period']['profileIdx2'])
 			->setActiveTab($data['active_tab'])
 			->addTimeSelector($data['time_period']['from'], $data['time_period']['to'],
@@ -251,14 +257,14 @@ $widget
 	->show();
 
 (new CScriptTag('
-	initializeView(
-		'.json_encode($data['dashboard']).',
-		'.json_encode($data['widget_defaults']).',
-		'.json_encode($data['has_time_selector']).',
-		'.json_encode($data['time_period']).',
-		'.json_encode($data['dynamic']).',
-		'.json_encode($web_layout_mode).'
-	);
+	view.init('.json_encode([
+		'dashboard' => $data['dashboard'],
+		'widget_defaults' => $data['widget_defaults'],
+		'has_time_selector' => $data['has_time_selector'],
+		'time_period' => $data['time_period'],
+		'dynamic' => $data['dynamic'],
+		'web_layout_mode' => $web_layout_mode
+	]).');
 '))
 	->setOnDocumentReady()
 	->show();
