@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 
 /**
  * @var CView $this
+ * @var array $data
  */
 
 // indicator of sort field
@@ -30,13 +31,21 @@ $sort_div = (new CSpan())
 // create alert table
 $table = (new CTableInfo())
 	->setHeader([
-		($data['sortfield'] === 'clock') ? [_('Time'), $sort_div] : _('Time'),
-		_('Action'),
-		($data['sortfield'] === 'mediatypeid') ? [_('Type'), $sort_div] : _('Type'),
-		($data['sortfield'] === 'sendto') ? [_('Recipient'), $sort_div] : _('Recipient'),
-		_('Message'),
-		($data['sortfield'] === 'status') ? [_('Status'), $sort_div] : _('Status'),
-		_('Info')
+		($data['sortfield'] === 'clock')
+			? [_x('Time', 'compact table header'), $sort_div]
+			: _x('Time', 'compact table header'),
+		_x('Action', 'compact table header'),
+		($data['sortfield'] === 'mediatypeid')
+			? [_x('Type', 'compact table header'), $sort_div]
+			: _x('Type', 'compact table header'),
+		($data['sortfield'] === 'sendto')
+			? [_x('Recipient', 'compact table header'), $sort_div]
+			: _x('Recipient', 'compact table header'),
+		_x('Message', 'compact table header'),
+		($data['sortfield'] === 'status')
+			? [_x('Status', 'compact table header'), $sort_div]
+			: _x('Status', 'compact table header'),
+		_x('Info', 'compact table header')
 	]);
 
 foreach ($data['alerts'] as $alert) {
@@ -53,24 +62,35 @@ foreach ($data['alerts'] as $alert) {
 		$info_icons = null;
 	}
 
+	$message = ($alert['alerttype'] == ALERT_TYPE_MESSAGE)
+		? [
+			bold($alert['subject']),
+			BR(),
+			BR(),
+			zbx_nl2br($alert['message'])
+		]
+		: [
+			zbx_nl2br($alert['message'])
+		];
+
 	$table->addRow([
 		zbx_date2str(DATE_TIME_FORMAT_SECONDS, $alert['clock']),
 		array_key_exists($alert['actionid'], $data['actions']) ? $data['actions'][$alert['actionid']]['name'] : '',
 		$alert['description'],
 		makeEventDetailsTableUser($alert, $data['db_users']),
-		[bold($alert['subject']), BR(), BR(), zbx_nl2br($alert['message'])],
+		$message,
 		makeActionTableStatus($alert),
 		makeInformationList($info_icons)
 	]);
 }
 
 $output = [
-	'header' => $data['name'],
+	'name' => $data['name'],
 	'body' => $table->toString()
 ];
 
-if (($messages = getMessages()) !== null) {
-	$output['messages'] = $messages->toString();
+if ($messages = get_and_clear_messages()) {
+	$output['messages'] = array_column($messages, 'message');
 }
 
 if ($data['user']['debug_mode'] == GROUP_DEBUG_MODE_ENABLED) {
