@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -18,20 +18,37 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 **/
 
-$pageHeader = (new CPageHeader(_('Fatal error, please report to the Zabbix team')))
-	->addCssFile('styles/'.CHtml::encode($data['theme']).'.css')
+
+/**
+ * @var CView $this
+ */
+
+$pageHeader = (new CPageHeader(_('Fatal error, please report to the Zabbix team'), CWebUser::getLang()))
+	->addCssFile('assets/styles/'.CHtml::encode($data['theme']).'.css')
 	->display();
 
-$buttons = [
-	(new CButton('back', _('Go to dashboard')))
-		->onClick('javascript: document.location = "zabbix.php?action=dashboard.view"'
-)];
+if (CWebUser::isLoggedIn()) {
+	$buttons = [
+		(new CButton('back', _s('Go to "%1$s"', CMenuHelper::getFirstLabel())))
+			->setAttribute('data-url', CMenuHelper::getFirstUrl())
+			->onClick('document.location = this.dataset.url;')
+	];
+}
+else {
+	$buttons = [
+		(new CButton('login', _s('Go to "%1$s"', _('Login'))))
+			->setAttribute('data-url', 'index.php')
+			->onClick('document.location = this.dataset.url;')
+	];
+}
 
-echo '<body lang="'.CWebUser::getLang().'">';
+echo '<body';
 
-(new CTag('main', true,
+(new CDiv((new CTag('main', true,
 	new CWarning(_('Fatal error, please report to the Zabbix team'), $data['messages'], $buttons)
-))->show();
+))))
+	->addClass(ZBX_STYLE_LAYOUT_WRAPPER)
+	->show();
 
 echo '</body>';
 echo '</html>';
