@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -1671,7 +1671,8 @@ function getSingleEventActions(array $event, array $r_events, array $alerts) {
 	// Sort by action_type is done to put Recovery event before actions, resulted from it. Same for other action_type.
 	CArrayHelper::sort($actions, [
 		['field' => 'clock', 'order' => ZBX_SORT_DOWN],
-		['field' => 'action_type', 'order' => ZBX_SORT_DOWN]
+		['field' => 'action_type', 'order' => ZBX_SORT_DOWN],
+		['field' => 'alertid', 'order' => ZBX_SORT_DOWN]
 	]);
 
 	return [
@@ -2066,16 +2067,23 @@ function makeEventDetailsActionsTable(array $data, array $users, array $mediatyp
 		}
 
 		$message = '';
-		if ($action['action_type'] == ZBX_EVENT_HISTORY_ALERT && $action['alerttype'] == ALERT_TYPE_MESSAGE) {
-			$message = [bold($action['subject']), BR(), BR(), zbx_nl2br($action['message'])];
-		}
-		elseif (($action['action_type'] == ZBX_EVENT_HISTORY_ALERT && $action['alerttype'] == ALERT_TYPE_COMMAND)
-				|| $action['action_type'] == ZBX_EVENT_HISTORY_MANUAL_UPDATE) {
-			$message = [
-				bold(_('Command').':'),
-				BR(),
-				zbx_nl2br($action['message'])
-			];
+
+		switch ($action['action_type']) {
+			case ZBX_EVENT_HISTORY_ALERT:
+				switch ($action['alerttype']) {
+					case ALERT_TYPE_MESSAGE:
+						$message = [bold($action['subject']), BR(), BR(), zbx_nl2br($action['message'])];
+						break;
+
+					case ALERT_TYPE_COMMAND:
+						$message = [bold(_('Command').':'), BR(), zbx_nl2br($action['message'])];
+						break;
+				}
+				break;
+
+			case ZBX_EVENT_HISTORY_MANUAL_UPDATE:
+				$message = zbx_nl2br($action['message']);
+				break;
 		}
 
 		$table->addRow([
