@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -43,6 +43,7 @@ class CApiServiceFactory extends CRegistryFactory {
 		'graph' => CGraph::class,
 		'graphitem' => CGraphItem::class,
 		'graphprototype' => CGraphPrototype::class,
+		'hanode' => CHaNode::class,
 		'host' => CHost::class,
 		'hostgroup' => CHostGroup::class,
 		'hostprototype' => CHostPrototype::class,
@@ -61,18 +62,22 @@ class CApiServiceFactory extends CRegistryFactory {
 		'problem' => CProblem::class,
 		'proxy' => CProxy::class,
 		'report' => CReport::class,
+		'regexp' => CRegexp::class,
 		'role' => CRole::class,
 		'service' => CService::class,
+		'sla' => CSla::class,
 		'script' => CScript::class,
 		'settings' => CSettings::class,
 		'task' => CTask::class,
 		'template' => CTemplate::class,
 		'templatedashboard' => CTemplateDashboard::class,
+		'templategroup' => CTemplateGroup::class,
 		'token' => CToken::class,
 		'trend' => CTrend::class,
 		'trigger' => CTrigger::class,
 		'triggerprototype' => CTriggerPrototype::class,
 		'user' => CUser::class,
+		'userdirectory' => CUserDirectory::class,
 		'usergroup' => CUserGroup::class,
 		'usermacro' => CUserMacro::class,
 		'valuemap' => CValueMap::class
