@@ -1,7 +1,7 @@
-<?php declare(strict_types = 1);
+<?php declare(strict_types = 0);
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -85,6 +85,7 @@ class CSettingsHelper extends CConfigGeneralHelper {
 	public const GEOMAPS_MAX_ZOOM = 'geomaps_max_zoom';
 	public const GEOMAPS_ATTRIBUTION = 'geomaps_attribution';
 	public const HA_FAILOVER_DELAY = 'ha_failover_delay';
+	public const VAULT_PROVIDER = 'vault_provider';
 
 	/**
 	 * Settings API object parameters array.
@@ -128,4 +129,17 @@ class CSettingsHelper extends CConfigGeneralHelper {
 
 		return array_key_exists($name, self::$params) ? self::$params[$name] : null;
 	}
+
+	/**
+	 * @return array
+	 */
+	public static function getDbVersionStatus(): array {
+		$dbversion_status = json_decode((string) self::getGlobal(self::DBVERSION_STATUS), true);
+
+		if (!is_array($dbversion_status)) {
+			return [];
+		}
+
+		return $dbversion_status;
+	}
 }
