@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -70,6 +70,13 @@ class CDateSelector extends CTag {
 	 */
 	private $enabled = true;
 
+	/**
+	 * Maxlength attribute of the input field. Aligned with the date format by default.
+	 *
+	 * @var int
+	 */
+	private $maxlength;
+
 	/**
 	 * Create array with all inputs required for date selection and calendar.
 	 *
@@ -115,7 +122,7 @@ class CDateSelector extends CTag {
 	/**
 	 * Add placeholder to date textbox field.
 	 *
-	 * @param type $text  Placeholder text for date textbox field.
+	 * @param string $text  Placeholder text for date textbox field.
 	 *
 	 * @return CDateSelector
 	 */
@@ -130,7 +137,7 @@ class CDateSelector extends CTag {
 	 *
 	 * @param bool $value
 	 *
-	 * @return self
+	 * @return CDateSelector
 	 */
 	public function setReadonly(bool $value): self {
 		$this->readonly = $value;
@@ -139,7 +146,7 @@ class CDateSelector extends CTag {
 	}
 
 	/**
-	 * Set enabled or disabled  state to field.
+	 * Set enabled or disabled state to field.
 	 *
 	 * @param bool $enabled  Field state.
 	 *
@@ -151,6 +158,19 @@ class CDateSelector extends CTag {
 		return $this;
 	}
 
+	/**
+	 * Set non-default maxlength attribute to the input field.
+	 *
+	 * @param int $maxlength
+	 *
+	 * @return CDateSelector
+	 */
+	public function setMaxLength(int $maxlength) {
+		$this->maxlength = $maxlength;
+
+		return $this;
+	}
+
 	/**
 	 * Gets string representation of date textbox and calendar button.
 	 *
@@ -164,7 +184,7 @@ class CDateSelector extends CTag {
 				(new CTextBox($this->name, $this->value))
 					->setId($this->name)
 					->setAttribute('placeholder', $this->placeholder)
-					->setAttribute('maxlength', strlen(date($this->date_format)))
+					->setAttribute('maxlength', $this->maxlength ?? strlen(date($this->date_format)))
 					->setAriaRequired($this->is_required)
 					->setEnabled($this->enabled)
 					->setReadonly($this->readonly)
