@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -21,23 +21,13 @@
 
 class CVisibilityBox extends CCheckBox {
 
-	public function __construct($name = 'visibilitybox', $object_name = null, $replace_to = null) {
-		if (!is_array($object_name)) {
-			$object_name = [$object_name];
-		}
-		$this->object_name = $object_name;
+	public function __construct($name = 'visibilitybox', $object_id = null, $replace_to = null) {
+		$this->object_id = $object_id;
 		$this->replace_to = unpack_object($replace_to);
 
-		$action = '';
-		foreach ($this->object_name as $obj_name) {
-			if (empty($obj_name)) {
-				continue;
-			}
-			$action .= 'visibility_status_changeds(this.checked, '.zbx_jsvalue($obj_name).', '.zbx_jsvalue($this->replace_to).');';
-		}
 		parent::__construct($name);
-		$this->onClick($action);
-		insert_javascript_for_visibilitybox();
+		$this->onClick('visibilityStatusChanges(this.checked, '.zbx_jsvalue($this->object_id).', '.
+			zbx_jsvalue($this->replace_to).');');
 	}
 
 	/**
@@ -48,7 +38,7 @@ class CVisibilityBox extends CCheckBox {
 	 * @return CVisibilityBox
 	 */
 	public function setLabel($label) {
-		parent::setLabel($label.SPACE);
+		parent::setLabel($label);
 		$this->setLabelPosition(self::LABEL_POSITION_LEFT);
 
 		return $this;
@@ -56,13 +46,10 @@ class CVisibilityBox extends CCheckBox {
 
 	public function toString($destroy = true) {
 		if (!isset($this->attributes['checked'])) {
-			foreach ($this->object_name as $obj_name) {
-				if (empty($obj_name)) {
-					continue;
-				}
-				zbx_add_post_js('visibility_status_changeds(false, '.zbx_jsvalue($obj_name).', '.zbx_jsvalue($this->replace_to).');');
-			}
+			zbx_add_post_js('visibilityStatusChanges(false, '.zbx_jsvalue($this->object_id).', '.
+				zbx_jsvalue($this->replace_to).');');
 		}
+
 		return parent::toString($destroy);
 	}
 }
