@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -27,33 +27,31 @@ class CSvgPath extends CSvgTag {
 	public function __construct($directions = '') {
 		parent::__construct('path');
 
-		$this->setDirections($directions);
-	}
-
-	public function setDirections($directions) {
 		$this->directions = $directions;
 	}
 
-	public function moveTo($x, $y) {
+	public function moveTo($x, $y): self {
 		$this->directions .= ' M'.floor($x).','.ceil($y);
 
 		return $this;
 	}
 
-	public function lineTo($x, $y) {
+	public function lineTo($x, $y): self {
 		$this->directions .= ' L'.floor($x).','.ceil($y);
 
 		return $this;
 	}
 
-	public function closePath() {
+	public function closePath(): self {
 		$this->directions .= ' Z';
 
 		return $this;
 	}
 
-	public function toString($destroy = true) {
-		$this->setAttribute('d', trim($this->directions));
+	public function toString($destroy = true): string {
+		if (trim($this->directions) !== '') {
+			$this->setAttribute('d', trim($this->directions));
+		}
 
 		return parent::toString($destroy);
 	}
