@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -20,13 +20,18 @@
 
 
 class CWidget {
+
 	private const ZBX_STYLE_HEADER_TITLE = 'header-title';
+	private const ZBX_STYLE_HEADER_DOC_LINK = 'header-doc-link';
 	private const ZBX_STYLE_HEADER_NAVIGATION = 'header-navigation';
 	private const ZBX_STYLE_HEADER_CONTROLS = 'header-controls';
+	private const ZBX_STYLE_HEADER_KIOSKMODE_CONTROLS = 'header-kioskmode-controls';
 
 	private $title;
 	private $title_submenu;
+	private $doc_url;
 	private $controls;
+	private $kiosk_mode_controls;
 
 	/**
 	 * Navigation, displayed exclusively in ZBX_LAYOUT_NORMAL mode.
@@ -61,12 +66,24 @@ class CWidget {
 		return $this;
 	}
 
+	public function setDocUrl($doc_url) {
+		$this->doc_url = $doc_url;
+
+		return $this;
+	}
+
 	public function setControls($controls) {
 		$this->controls = $controls;
 
 		return $this;
 	}
 
+	public function setKioskModeControls($kiosk_mode_controls) {
+		$this->kiosk_mode_controls = $kiosk_mode_controls;
+
+		return $this;
+	}
+
 	/**
 	 * Set layout mode.
 	 *
@@ -112,11 +129,16 @@ class CWidget {
 
 		if ($this->web_layout_mode == ZBX_LAYOUT_KIOSKMODE) {
 			$this->addItem(
-				get_icon('kioskmode', ['mode' => ZBX_LAYOUT_KIOSKMODE])
-					->setAttribute('aria-label', _('Content controls'))
+				(new CList())
+					->addClass(self::ZBX_STYLE_HEADER_KIOSKMODE_CONTROLS)
+					->addItem($this->kiosk_mode_controls)
+					->addItem(
+						get_icon('kioskmode', ['mode' => ZBX_LAYOUT_KIOSKMODE])
+							->setAttribute('aria-label', _('Content controls'))
+					)
 			);
 		}
-		elseif ($this->title !== null || $this->controls !== null) {
+		elseif ($this->title !== null || $this->controls !== null || $this->doc_url !== null) {
 			$items[] = $this->createTopHeader();
 		}
 
@@ -135,7 +157,7 @@ class CWidget {
 		return unpack_object($items);
 	}
 
-	private function createTopHeader() {
+	private function createTopHeader(): CTag {
 		$divs = [
 			(new CTag('nav', true, (new CButton(null, _('Show sidebar')))
 				->setId('sidebar-button-toggle')
@@ -167,6 +189,15 @@ class CWidget {
 			$divs[] = new CDiv($title_tag);
 		}
 
+		if ($this->doc_url !== null) {
+			$divs[] = (new CDiv(
+				(new CLink(null, $this->doc_url))
+					->setTitle(_('Help'))
+					->setTarget('_blank')
+					->addClass(ZBX_STYLE_ICON_DOC_LINK)
+			))->addClass(self::ZBX_STYLE_HEADER_DOC_LINK);
+		}
+
 		if ($this->controls !== null) {
 			$divs[] = (new CDiv($this->controls))->addClass(self::ZBX_STYLE_HEADER_CONTROLS);
 		}
