@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -105,6 +105,15 @@ class CApiInputValidator {
 			case API_UINTS64:
 				return self::validateUInts64($rule, $data, $path, $error);
 
+			case API_FILTER:
+				return self::validateFilter($rule, $data, $path, $error);
+
+			case API_FILTER_VALUES:
+				return self::validateFilterValues($rule, $data, $path, $error);
+
+			case API_FILTER_VALUE:
+				return self::validateFilterValue($rule, $data, $path, $error);
+
 			case API_FLOAT:
 				return self::validateFloat($rule, $data, $path, $error);
 
@@ -263,6 +272,9 @@ class CApiInputValidator {
 			case API_INT32_RANGES:
 			case API_UINT64:
 			case API_UINTS64:
+			case API_FILTER:
+			case API_FILTER_VALUES:
+			case API_FILTER_VALUE:
 			case API_FLOAT:
 			case API_FLOATS:
 			case API_ID:
@@ -305,28 +317,7 @@ class CApiInputValidator {
 				return true;
 
 			case API_OBJECT:
-				foreach ($rule['fields'] as $field_name => $field_rule) {
-					if ($data !== null && array_key_exists($field_name, $data)) {
-						if ($field_rule['type'] === API_MULTIPLE) {
-							foreach ($field_rule['rules'] as $multiple_rule) {
-								if (array_key_exists('else', $multiple_rule)
-										|| (is_array($multiple_rule['if'])
-											&& self::isInRange($data[$multiple_rule['if']['field']], $multiple_rule['if']['in']))
-										|| ($multiple_rule['if'] instanceof Closure
-											&& call_user_func($multiple_rule['if'], $data))) {
-									$field_rule = $multiple_rule;
-									break;
-								}
-							}
-						}
-
-						$subpath = ($path === '/' ? $path : $path.'/').$field_name;
-						if (!self::validateDataUniqueness($field_rule, $data[$field_name], $subpath, $error)) {
-							return false;
-						}
-					}
-				}
-				return true;
+				return self::validateObjectUniqueness($rule, $data, $path, $error);
 
 			case API_IDS:
 			case API_STRINGS_UTF8:
@@ -339,7 +330,7 @@ class CApiInputValidator {
 				return self::validateObjectsUniqueness($rule, $data, $path, $error);
 		}
 
-		// This message can be untranslated because warn about incorrect validation rules at a development stage.
+		// For use by developers. Do not translate.
 		$error = 'Incorrect validation rules.';
 
 		return false;
@@ -734,7 +725,7 @@ class CApiInputValidator {
 			return false;
 		}
 
-		if (bccomp($data, ZBX_MIN_INT32) == -1 || bccomp($data, ZBX_MAX_INT32) == 1) {
+		if ($data < ZBX_MIN_INT32 || $data > ZBX_MAX_INT32) {
 			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('a number is too large'));
 			return false;
 		}
@@ -838,6 +829,97 @@ class CApiInputValidator {
 		return true;
 	}
 
+	/**
+	 * Filter validator.
+	 *
+	 * @param array  $rule
+	 * @param int    $rule['flags']   (optional) API_ALLOW_NULL
+	 * @param array  $rule['fields']
+	 * @param mixed  $data
+	 * @param string $path
+	 * @param string $error
+	 *
+	 * @return bool
+	 */
+	private static function validateFilter($rule, &$data, $path, &$error) {
+		$rule['fields'] = array_flip($rule['fields']);
+
+		foreach ($rule['fields'] as &$field_rule) {
+			$field_rule = ['type' => API_FILTER_VALUES, 'flags' => API_ALLOW_NULL | API_NORMALIZE];
+		}
+		unset($field_rule);
+
+		return self::validateData(['type' => API_OBJECT] + $rule, $data, $path, $error);
+	}
+
+	/**
+	 * Filter values validator.
+	 *
+	 * @param array  $rule
+	 * @param int    $rule['flags']   (optional) API_ALLOW_NULL, API_NORMALIZE
+	 * @param mixed  $data
+	 * @param string $path
+	 * @param string $error
+	 *
+	 * @return bool
+	 */
+	private static function validateFilterValues($rule, &$data, $path, &$error) {
+		$flags = array_key_exists('flags', $rule) ? $rule['flags'] : 0x00;
+
+		if (($flags & API_ALLOW_NULL) && $data === null) {
+			return true;
+		}
+
+		if (($flags & API_NORMALIZE) && self::validateFilterValue([], $data, '', $e)) {
+			$data = [$data];
+		}
+		unset($e);
+
+		if (!is_array($data)) {
+			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('an array is expected'));
+			return false;
+		}
+
+		$data = array_values($data);
+		$rules = ['type' => API_FILTER_VALUE];
+
+		foreach ($data as $index => &$value) {
+			$subpath = ($path === '/' ? $path : $path.'/').($index + 1);
+			if (!self::validateData($rules, $value, $subpath, $error)) {
+				return false;
+			}
+		}
+		unset($value);
+
+		return true;
+	}
+
+	/**
+	 * Filter value validator.
+	 *
+	 * @param array  $rule
+	 * @param mixed  $data
+	 * @param string $path
+	 * @param string $error
+	 *
+	 * @return bool
+	 */
+	private static function validateFilterValue($rule, &$data, $path, &$error) {
+		if (!is_string($data) && !is_double($data) && !is_int($data)) {
+			$error = _s('Invalid parameter "%1$s": %2$s.', $path,
+				_('a character string, integer or floating point value is expected')
+			);
+			return false;
+		}
+
+		if (is_string($data) &&  mb_check_encoding($data, 'UTF-8') !== true) {
+			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('invalid byte sequence in UTF-8'));
+			return false;
+		}
+
+		return true;
+	}
+
 	/**
 	 * Floating point number validator.
 	 *
@@ -1114,7 +1196,6 @@ class CApiInputValidator {
 	 * Identifier validator.
 	 *
 	 * @param array  $rule
-	 * @param int    $rule['flags']   (optional) API_ALLOW_NULL, API_NOT_EMPTY
 	 * @param mixed  $data
 	 * @param string $path
 	 * @param string $error
@@ -1122,22 +1203,11 @@ class CApiInputValidator {
 	 * @return bool
 	 */
 	private static function validateId($rule, &$data, $path, &$error) {
-		$flags = array_key_exists('flags', $rule) ? $rule['flags'] : 0x00;
-
-		if (($flags & API_ALLOW_NULL) && $data === null) {
-			return true;
-		}
-
 		if (!is_scalar($data) || is_bool($data) || is_double($data) || !ctype_digit(strval($data))) {
 			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('a number is expected'));
 			return false;
 		}
 
-		if (($flags & API_NOT_EMPTY) && $data == 0) {
-			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('cannot be empty'));
-			return false;
-		}
-
 		if (bccomp($data, ZBX_DB_MAX_ID) > 0) {
 			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('a number is too large'));
 			return false;
@@ -1257,33 +1327,34 @@ class CApiInputValidator {
 
 		// validation of the values type
 		foreach ($rule['fields'] as $field_name => $field_rule) {
-			if ($field_rule['type'] === API_MULTIPLE) {
+			while ($field_rule['type'] == API_MULTIPLE) {
+				$matched_multiple_rule = null;
+
 				foreach ($field_rule['rules'] as $multiple_rule) {
 					if (array_key_exists('else', $multiple_rule)
 							|| (is_array($multiple_rule['if'])
 								&& self::isInRange($data[$multiple_rule['if']['field']], $multiple_rule['if']['in']))
 							|| ($multiple_rule['if'] instanceof Closure
 								&& call_user_func($multiple_rule['if'], $data))) {
-						if ($multiple_rule['type'] == API_UNEXPECTED
-								&& !self::validateUnexpected($field_name, $multiple_rule, $data, $path, $error)) {
-							return false;
-						}
-
 						$field_rule += ['flags' => 0x00];
 						$multiple_rule += ['flags' => 0x00];
 						$multiple_rule['flags'] = ($field_rule['flags'] & API_REQUIRED) | $multiple_rule['flags'];
-						$field_rule = $multiple_rule +
+						$matched_multiple_rule = $multiple_rule +
 							array_intersect_key($field_rule, array_flip(['default', 'default_source']));
 						break;
 					}
 				}
 
-				if ($field_rule['type'] === API_MULTIPLE) {
-					$error = 'Incorrect validation rules.';
+				if ($matched_multiple_rule === null) {
+					// For use by developers. Do not translate.
+					$error = 'Incorrect API_MULTIPLE validation rules.';
 					return false;
 				}
+
+				$field_rule = $matched_multiple_rule;
 			}
-			elseif ($field_rule['type'] === API_UNEXPECTED
+
+			if ($field_rule['type'] === API_UNEXPECTED
 					&& !self::validateUnexpected($field_name, $field_rule, $data, $path, $error)) {
 				return false;
 			}
@@ -2111,7 +2182,6 @@ class CApiInputValidator {
 	 * @return bool
 	 */
 	private static function validateObjectsUniqueness($rule, ?array $data, $path, &$error) {
-		// $data can be NULL when API_ALLOW_NULL is set
 		if ($data === null) {
 			return true;
 		}
@@ -2162,25 +2232,60 @@ class CApiInputValidator {
 		}
 
 		foreach ($data as $index => $object) {
-			foreach ($rule['fields'] as $field_name => $field_rule) {
-				if (array_key_exists($field_name, $object)) {
-					if ($field_rule['type'] === API_MULTIPLE) {
-						foreach ($field_rule['rules'] as $multiple_rule) {
-							if (array_key_exists('else', $multiple_rule)
-									|| (is_array($multiple_rule['if'])
-										&& self::isInRange($object[$multiple_rule['if']['field']], $multiple_rule['if']['in']))
-									|| ($multiple_rule['if'] instanceof Closure
-										&& call_user_func($multiple_rule['if'], $object))) {
-								$field_rule = $multiple_rule;
-								break;
-							}
+			$subpath = ($path === '/' ? $path : $path.'/').($index + 1);
+
+			if (!self::validateObjectUniqueness(['fields' => $rule['fields']], $object, $subpath, $error)) {
+				return false;
+			}
+		}
+
+		return true;
+	}
+
+	/**
+	 * Object uniqueness validator.
+	 *
+	 * @param            $rule
+	 * @param array|null $data
+	 * @param            $path
+	 * @param            $error
+	 *
+	 * @return bool
+	 */
+	private static function validateObjectUniqueness($rule, ?array $data, $path, &$error): bool {
+		if ($data === null) {
+			return true;
+		}
+
+		foreach ($rule['fields'] as $field_name => $field_rule) {
+			if (array_key_exists($field_name, $data)) {
+				while ($field_rule['type'] == API_MULTIPLE) {
+					$matched_multiple_rule = null;
+
+					foreach ($field_rule['rules'] as $multiple_rule) {
+						if (array_key_exists('else', $multiple_rule)
+								|| (is_array($multiple_rule['if']) && self::isInRange(
+									$data[$multiple_rule['if']['field']], $multiple_rule['if']['in']))
+								|| ($multiple_rule['if'] instanceof Closure
+									&& call_user_func($multiple_rule['if'], $data))) {
+							$matched_multiple_rule = $multiple_rule;
+							break;
 						}
 					}
 
-					$subpath = ($path === '/' ? $path : $path.'/').($index + 1).'/'.$field_name;
-					if (!self::validateDataUniqueness($field_rule, $object[$field_name], $subpath, $error)) {
+					if ($matched_multiple_rule === null) {
+						// For use by developers. Do not translate.
+						$error = 'Incorrect API_MULTIPLE validation rules.';
 						return false;
 					}
+
+					$field_rule = $matched_multiple_rule;
+				}
+
+				$subpath = ($path === '/' ? $path : $path.'/').$field_name;
+
+				if (!self::validateDataUniqueness($field_rule, $data[$field_name], $subpath, $error)) {
+					return false;
 				}
 			}
 		}
