@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -589,7 +589,7 @@ function convertUnitsS($value, $ignore_millisec = false) {
 
 	$units = [
 		'years' => _x('y', 'year short'),
-		'months' => _x('m', 'month short'),
+		'months' => _x('M', 'month short'),
 		'days' => _x('d', 'day short'),
 		'hours' => _x('h', 'hour short'),
 		'minutes' => _x('m', 'minute short'),
@@ -606,6 +606,72 @@ function convertUnitsS($value, $ignore_millisec = false) {
 	return $result ? ($value < 0 ? '-' : '').implode(' ', $result) : '0';
 }
 
+/**
+ * Convert time period to a human-readable format.
+ * The following units will be used: weeks, days, hours, minutes and seconds.
+ * Only the 3 most significant units will be displayed: #w #d #h, #d #h #m or #h #m #s, omitting empty ones.
+ *
+ * @param int $value  Time period in seconds.
+ *
+ * @return string
+ */
+function convertSecondsToTimeUnits(int $value): string {
+	$parts = [];
+	$start = null;
+
+	if (($v = floor($value / SEC_PER_WEEK)) > 0) {
+		$parts['weeks'] = $v;
+		$value -= $v * SEC_PER_WEEK;
+		$start = 0;
+	}
+
+	$level = 1;
+
+	foreach ([
+		'days' => SEC_PER_DAY,
+		'hours' => SEC_PER_HOUR,
+		'minutes' => SEC_PER_MIN
+	] as $part => $sec_per_part) {
+		$v = floor($value / $sec_per_part);
+
+		if ($v > 0) {
+			$parts[$part] = $v;
+			$value -= $v * $sec_per_part;
+			$start = $start === null ? $level : $start;
+		}
+
+		if ($start !== null && $level - $start >= 2) {
+			break;
+		}
+
+		$level++;
+	}
+
+	if ($start === null || $start >= 2) {
+		$v = $value + round(fmod($value, 1), ZBX_UNITS_ROUNDOFF_SUFFIXED);
+
+		if ($v > 0) {
+			$parts['seconds'] = $v;
+		}
+	}
+
+	$units = [
+		'weeks' => _x('w', 'week short'),
+		'days' => _x('d', 'day short'),
+		'hours' => _x('h', 'hour short'),
+		'minutes' => _x('m', 'minute short'),
+		'seconds' => _x('s', 'second short')
+	];
+
+	$result = [];
+
+	foreach ($parts as $part_unit => $part_value) {
+		$result[] = $part_value.$units[$part_unit];
+	}
+
+	return $result ? implode(' ', $result) : '0';
+}
+
 /**
  * Converts a raw value to a user-friendly representation based on unit and other parameters.
  * Example:
@@ -835,6 +901,10 @@ function zbx_empty($value) {
 }
 
 function zbx_is_int($var) {
+	if (is_array($var)) {
+		return false;
+	}
+
 	if (is_int($var)) {
 		return true;
 	}
@@ -1745,8 +1815,7 @@ function filter_messages(): array {
 
 		$generic_exists = false;
 		foreach ($messages as $message) {
-			if ($message['type'] === CMessageHelper::MESSAGE_TYPE_ERROR
-					&& ($message['source'] === 'sql' || $message['source'] === 'php')) {
+			if ($message['type'] === CMessageHelper::MESSAGE_TYPE_ERROR	&& $message['is_technical_error']) {
 				if (!$generic_exists) {
 					CMessageHelper::addError(_('System error occurred. Please contact Zabbix administrator.'));
 					$generic_exists = true;
@@ -2032,17 +2101,17 @@ function warning($messages): void {
 	}
 }
 
-/*
+/**
  * Add an error to global message array.
  *
- * @param string | array $msg	Error message text.
- * @param string		 $src	The source of error message.
+ * @param string|array $msgs                Error message text.
+ * @param bool         $is_technical_error
  */
-function error($msgs, string $src = ''): void {
+function error($msgs, bool $is_technical_error = false): void {
 	$msgs = zbx_toArray($msgs);
 
 	foreach ($msgs as $msg) {
-		CMessageHelper::addError($msg, $src);
+		CMessageHelper::addError($msg, $is_technical_error);
 	}
 }
 
@@ -2165,17 +2234,11 @@ function hasErrorMessages() {
 /**
  * Clears table rows selection's cookies.
  *
- * @param string $parentid  parent ID, is used as sessionStorage suffix
- * @param array  $keepids   checked rows ids
+ * @param string $name     entity name, used as sessionStorage suffix
+ * @param array  $keepids  checked rows ids
  */
-function uncheckTableRows($parentid = null, $keepids = []) {
-	if ($parentid === null) {
-		$key = implode('_', ['cb', basename($_SERVER['SCRIPT_NAME'], '.php')]);
-	}
-	else {
-		// Allow $parentid to be zero. For example actionconf.php uses $parentid as event source.
-		$key = implode('_', ['cb', basename($_SERVER['SCRIPT_NAME'], '.php'), $parentid]);
-	}
+function uncheckTableRows($name = null, $keepids = []) {
+	$key = 'cb_'.basename($_SERVER['SCRIPT_NAME'], '.php').($name !== null ? '_'.$name : '');
 
 	if ($keepids) {
 		$keepids = array_fill_keys($keepids, '');
@@ -2301,7 +2364,7 @@ function zbx_err_handler($errno, $errstr, $errfile, $errline) {
 	}
 
 	// Don't show the call to this handler function.
-	error($errstr.' ['.CProfiler::getInstance()->formatCallStack().']', 'php');
+	error($errstr.' ['.CProfiler::getInstance()->formatCallStack().']', true);
 
 	return false;
 }
