@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -28,26 +28,28 @@ $widget = new CWidget();
 if ($data['parent_discoveryid'] === null) {
 	$widget
 		->setTitle(_('Graphs'))
+		->setDocUrl(CDocHelper::getUrl(CDocHelper::CONFIGURATION_GRAPH_EDIT))
 		->setNavigation(getHostNavigation('graphs', $data['hostid']));
 }
 else {
 	$widget
 		->setTitle(_('Graph prototypes'))
+		->setDocUrl(CDocHelper::getUrl(CDocHelper::CONFIGURATION_PROTOTYPE_GRAPH_EDIT))
 		->setNavigation(getHostNavigation('graphs', $data['hostid'], $data['parent_discoveryid']));
 }
 
 $url = (new CUrl('graphs.php'))
+	->setArgument('parent_discoveryid', $data['parent_discoveryid'])
 	->setArgument('context', $data['context'])
 	->getUrl();
 
 // Create form.
 $graphForm = (new CForm('post', $url))
+	->addItem((new CVar('form_refresh', $data['form_refresh'] + 1))->removeId())
 	->setName('graphForm')
-	->setAttribute('aria-labeledby', ZBX_STYLE_PAGE_TITLE)
-	->addVar('form', $this->data['form'])
-	->addVar('hostid', $this->data['hostid'])
-	->addVar('ymin_itemid', $this->data['ymin_itemid'])
-	->addVar('ymax_itemid', $this->data['ymax_itemid']);
+	->setAttribute('aria-labelledby', ZBX_STYLE_PAGE_TITLE)
+	->addVar('form', $data['form'])
+	->addVar('hostid', $data['hostid']);
 
 if ($data['parent_discoveryid'] !== null) {
 	$graphForm->addItem((new CVar('parent_discoveryid', $data['parent_discoveryid']))->removeId());
@@ -60,7 +62,7 @@ if ($data['graphid'] != 0) {
 // Create form list.
 $graphFormList = new CFormList('graphFormList');
 
-$is_templated = (bool) $this->data['templates'];
+$is_templated = (bool) $data['templates'];
 if ($is_templated) {
 	$graphFormList->addRow(_('Parent graphs'), $data['templates']);
 }
@@ -73,6 +75,7 @@ if (array_key_exists('flags', $data) && $data['flags'] == ZBX_FLAG_DISCOVERY_CRE
 $readonly = false;
 if ($is_templated || $discovered_graph) {
 	$readonly = true;
+	$graphForm->addItem((new CVar('readonly', 1))->removeId());
 }
 
 if ($discovered_graph) {
@@ -88,18 +91,18 @@ if ($discovered_graph) {
 $graphFormList
 	->addRow(
 		(new CLabel(_('Name'), 'name'))->setAsteriskMark(),
-		(new CTextBox('name', $this->data['name'], $readonly))
+		(new CTextBox('name', $data['name'], $readonly, DB::getFieldLength('graphs', 'name')))
 			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 			->setAriaRequired()
 			->setAttribute('autofocus', 'autofocus')
 	)
 	->addRow((new CLabel(_('Width'), 'width'))->setAsteriskMark(),
-		(new CNumericBox('width', $this->data['width'], 5, $readonly))
+		(new CNumericBox('width', $data['width'], 5, $readonly))
 			->setWidth(ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH)
 			->setAriaRequired()
 	)
 	->addRow((new CLabel(_('Height'), 'height'))->setAsteriskMark(),
-		(new CNumericBox('height', $this->data['height'], 5, $readonly))
+		(new CNumericBox('height', $data['height'], 5, $readonly))
 			->setWidth(ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH)
 			->setAriaRequired()
 	)
@@ -107,150 +110,158 @@ $graphFormList
 		(new CSelect('graphtype'))
 			->setId('graphtype')
 			->setFocusableElementId('label-graphtype')
-			->setValue($this->data['graphtype'])
+			->setValue($data['graphtype'])
 			->addOptions(CSelect::createOptionsFromArray(graphType()))
 			->setDisabled($readonly)
 	)
 	->addRow(_('Show legend'),
 		(new CCheckBox('show_legend'))
-			->setChecked($this->data['show_legend'] == 1)
+			->setChecked($data['show_legend'] == 1)
 			->setEnabled(!$readonly)
 	);
 
 // Append graph types to form list.
-if ($this->data['graphtype'] == GRAPH_TYPE_NORMAL || $this->data['graphtype'] == GRAPH_TYPE_STACKED) {
+if ($data['graphtype'] == GRAPH_TYPE_NORMAL || $data['graphtype'] == GRAPH_TYPE_STACKED) {
 	$graphFormList->addRow(_('Show working time'),
 		(new CCheckBox('show_work_period'))
-			->setChecked($this->data['show_work_period'] == 1)
+			->setChecked($data['show_work_period'] == 1)
 			->setEnabled(!$readonly)
 	);
 	$graphFormList->addRow(_('Show triggers'),
 		(new CCheckbox('show_triggers'))
-			->setchecked($this->data['show_triggers'] == 1)
+			->setchecked($data['show_triggers'] == 1)
 			->setEnabled(!$readonly)
 	);
 
-	if ($this->data['graphtype'] == GRAPH_TYPE_NORMAL) {
+	if ($data['graphtype'] == GRAPH_TYPE_NORMAL) {
 		// Percent left.
-		$percentLeftTextBox = (new CTextBox('percent_left', $this->data['percent_left'], $readonly, 7))
+		$percentLeftTextBox = (new CTextBox('percent_left', $data['percent_left'], $readonly, 7))
 			->setWidth(ZBX_TEXTAREA_TINY_WIDTH);
 		$percentLeftCheckbox = (new CCheckBox('visible[percent_left]'))
 			->setChecked(true)
-			->onClick('javascript: showHideVisible("percent_left");')
+			->onClick('showHideVisible("percent_left");')
 			->setEnabled(!$readonly);
 
-		if(isset($this->data['visible']) && isset($this->data['visible']['percent_left'])) {
+		if(array_key_exists('visible', $data) && array_key_exists('percent_left', $data['visible'])) {
 			$percentLeftCheckbox->setChecked(true);
 		}
-		elseif ($this->data['percent_left'] == 0) {
+		elseif ($data['percent_left'] == 0) {
 			$percentLeftTextBox->addStyle('visibility: hidden;');
 			$percentLeftCheckbox->setChecked(false);
 		}
 
-		$graphFormList->addRow(_('Percentile line (left)'), [$percentLeftCheckbox, SPACE, $percentLeftTextBox]);
+		$graphFormList->addRow(_('Percentile line (left)'), [$percentLeftCheckbox, ' ', $percentLeftTextBox]);
 
 		// Percent right.
-		$percentRightTextBox = (new CTextBox('percent_right', $this->data['percent_right'], $readonly, 7))
+		$percentRightTextBox = (new CTextBox('percent_right', $data['percent_right'], $readonly, 7))
 			->setWidth(ZBX_TEXTAREA_TINY_WIDTH);
 		$percentRightCheckbox = (new CCheckBox('visible[percent_right]'))
 			->setChecked(true)
-			->onClick('javascript: showHideVisible("percent_right");')
+			->onClick('showHideVisible("percent_right");')
 			->setEnabled(!$readonly);
 
-		if(isset($this->data['visible']) && isset($this->data['visible']['percent_right'])) {
+		if(array_key_exists('visible', $data) && array_key_exists('percent_right', $data['visible'])) {
 			$percentRightCheckbox->setChecked(true);
 		}
-		elseif ($this->data['percent_right'] == 0) {
+		elseif ($data['percent_right'] == 0) {
 			$percentRightTextBox->addStyle('visibility: hidden;');
 			$percentRightCheckbox->setChecked(false);
 		}
 
-		$graphFormList->addRow(_('Percentile line (right)'), [$percentRightCheckbox, SPACE, $percentRightTextBox]);
+		$graphFormList->addRow(_('Percentile line (right)'), [$percentRightCheckbox, ' ', $percentRightTextBox]);
 	}
 
 	$yaxisMinData = [];
 	$yaxisMinData[] = (new CSelect('ymin_type'))
 		->setId('ymin_type')
-		->setValue($this->data['ymin_type'])
+		->setValue($data['ymin_type'])
 		->addOptions(CSelect::createOptionsFromArray([
 			GRAPH_YAXIS_TYPE_CALCULATED => _('Calculated'),
 			GRAPH_YAXIS_TYPE_FIXED => _('Fixed'),
 			GRAPH_YAXIS_TYPE_ITEM_VALUE => _('Item')
 		]))
-		->setDisabled($readonly);
+		->setDisabled($readonly)
+		->setFocusableElementId('ymin_type_label');
 
-	if ($this->data['ymin_type'] == GRAPH_YAXIS_TYPE_FIXED) {
+	if ($data['ymin_type'] == GRAPH_YAXIS_TYPE_FIXED) {
 		$yaxisMinData[] = (new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN);
-		$yaxisMinData[] = (new CTextBox('yaxismin', $this->data['yaxismin'], $readonly))
+		$yaxisMinData[] = (new CTextBox('yaxismin', $data['yaxismin'], $readonly))
 			->setWidth(ZBX_TEXTAREA_SMALL_WIDTH);
 	}
-	elseif ($this->data['ymin_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
-		$graphForm->addVar('yaxismin', $this->data['yaxismin']);
+	elseif ($data['ymin_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
+		$graphForm->addVar('yaxismin', $data['yaxismin']);
 
-		$ymin_name = '';
-		if (!empty($this->data['ymin_itemid'])) {
-			$min_host = get_host_by_itemid($this->data['ymin_itemid']);
+		$ymin_axis_ms_data = [];
 
-			$minItems = CMacrosResolverHelper::resolveItemNames([get_item_by_itemid($this->data['ymin_itemid'])]);
-			$minItem = reset($minItems);
-
-			$ymin_name = $min_host['name'].NAME_DELIMITER.$minItem['name_expanded'];
+		if ($data['ymin_itemid'] != 0) {
+			if (array_key_exists($data['ymin_itemid'], $data['yaxis_items'])) {
+				$ymin_axis_ms_data = [[
+					'id' => $data['ymin_itemid'],
+					'name' => $data['yaxis_items'][$data['ymin_itemid']]['name'],
+					'prefix' => $data['yaxis_items'][$data['ymin_itemid']]['hosts'][0]['name'].NAME_DELIMITER
+				]];
+			}
+			else {
+				$ymin_axis_ms_data = [[
+					'id' => $data['ymin_itemid'],
+					'name' => _('Inaccessible item'),
+					'prefix' => ''
+				]];
+			}
 		}
 
 		$yaxisMinData[] = (new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN);
-		$yaxisMinData[] = (new CTextBox('ymin_name', $ymin_name, true))
-			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
-			->setAriaRequired();
-		$yaxisMinData[] = (new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN);
 
-		// Select item button.
-		$yaxisMinData[] = (new CButton('yaxis_min', _('Select')))
-			->addClass(ZBX_STYLE_BTN_GREY)
-			->onClick('return PopUp("popup.generic",jQuery.extend('.
-				json_encode([
+		$yaxisMinData[] = (new CMultiSelect([
+			'name' => 'ymin_itemid',
+			'object_name' => 'items',
+			'data' => $ymin_axis_ms_data,
+			'multiple' => false,
+			'disabled' => $readonly,
+			'styles' => [
+				'display' => 'inline-flex'
+			],
+			'popup' => [
+				'parameters' => [
 					'srctbl' => 'items',
 					'srcfld1' => 'itemid',
 					'srcfld2' => 'name',
 					'dstfrm' => $graphForm->getName(),
 					'dstfld1' => 'ymin_itemid',
-					'dstfld2' => 'ymin_name',
-					'with_webitems' => '1',
+					'hostid' => $data['is_template'] ? $data['hostid'] : 0,
 					'numeric' => '1',
-					'writeonly' => '1'
-				]).
-					',getOnlyHostParam()), null, this);'
-			)
-			->setEnabled(!$readonly);
+					'real_hosts' => !$data['is_template']
+				]
+			]
+		]))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH);
 
 		// Select item prototype button.
 		if ($data['parent_discoveryid'] !== null) {
 			$yaxisMinData[] = (new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN);
 			$yaxisMinData[] = (new CButton('yaxis_min_prototype', _('Select prototype')))
 				->addClass(ZBX_STYLE_BTN_GREY)
-				->onClick('return PopUp("popup.generic",'.
-					json_encode([
-						'srctbl' => 'item_prototypes',
-						'srcfld1' => 'itemid',
-						'srcfld2' => 'name',
-						'dstfrm' => $graphForm->getName(),
-						'dstfld1' => 'ymin_itemid',
-						'dstfld2' => 'ymin_name',
-						'parent_discoveryid' => $data['parent_discoveryid'],
-						'numeric' => '1'
-					]).', null, this);'
-				)
+				->setAttribute('data-parent_discoveryid', $data['parent_discoveryid'])
+				->onClick('
+					PopUp("popup.generic", {
+						srctbl: "item_prototypes",
+						srcfld1: "itemid",
+						srcfld2: "name",
+						dstfrm: "'.$graphForm->getName().'",
+						dstfld1: "ymin_itemid",
+						parent_discoveryid: this.dataset.parent_discoveryid,
+						numeric: 1
+					}, {dialogue_class: "modal-popup-generic"});
+				')
 				->setEnabled(!$readonly);
 		}
 	}
 	else {
-		$graphForm->addVar('yaxismin', $this->data['yaxismin']);
+		$graphForm->addVar('yaxismin', $data['yaxismin']);
 	}
 
-	$yaxismin_label = new CLabel(_('Y axis MIN value'));
-	if ($this->data['ymin_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
-		$yaxismin_label
-			->setAsteriskMark()
-			->setAttribute('for', 'ymin_name');
+	$yaxismin_label = new CLabel(_('Y axis MIN value'),'ymin_type_label');
+	if ($data['ymin_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
+		$yaxismin_label->setAsteriskMark();
 	}
 
 	$graphFormList->addRow($yaxismin_label, $yaxisMinData);
@@ -258,86 +269,93 @@ if ($this->data['graphtype'] == GRAPH_TYPE_NORMAL || $this->data['graphtype'] ==
 	$yaxisMaxData = [];
 	$yaxisMaxData[] = (new CSelect('ymax_type'))
 		->setId('ymax_type')
-		->setValue($this->data['ymax_type'])
+		->setValue($data['ymax_type'])
 		->addOptions(CSelect::createOptionsFromArray([
 			GRAPH_YAXIS_TYPE_CALCULATED => _('Calculated'),
 			GRAPH_YAXIS_TYPE_FIXED => _('Fixed'),
 			GRAPH_YAXIS_TYPE_ITEM_VALUE => _('Item')
 		]))
-		->setDisabled($readonly);
+		->setDisabled($readonly)
+		->setFocusableElementId('ymax_type_label');
 
-	if ($this->data['ymax_type'] == GRAPH_YAXIS_TYPE_FIXED) {
+	if ($data['ymax_type'] == GRAPH_YAXIS_TYPE_FIXED) {
 		$yaxisMaxData[] = (new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN);
-		$yaxisMaxData[] = (new CTextBox('yaxismax', $this->data['yaxismax'], $readonly))
-			->setWidth(ZBX_TEXTAREA_SMALL_WIDTH);
+		$yaxisMaxData[] = (new CTextBox('yaxismax', $data['yaxismax'], $readonly))->setWidth(ZBX_TEXTAREA_SMALL_WIDTH);
 	}
-	elseif ($this->data['ymax_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
-		$graphForm->addVar('yaxismax', $this->data['yaxismax']);
+	elseif ($data['ymax_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
+		$graphForm->addVar('yaxismax', $data['yaxismax']);
 
-		$ymax_name = '';
-		if (!empty($this->data['ymax_itemid'])) {
-			$max_host = get_host_by_itemid($this->data['ymax_itemid']);
+		$ymax_axis_ms_data = [];
 
-			$maxItems = CMacrosResolverHelper::resolveItemNames([get_item_by_itemid($this->data['ymax_itemid'])]);
-			$maxItem = reset($maxItems);
-
-			$ymax_name = $max_host['name'].NAME_DELIMITER.$maxItem['name_expanded'];
+		if ($data['ymax_itemid'] != 0) {
+			if (array_key_exists($data['ymax_itemid'], $data['yaxis_items'])) {
+				$ymax_axis_ms_data = [[
+					'id' => $data['ymax_itemid'],
+					'name' => $data['yaxis_items'][$data['ymax_itemid']]['name'],
+					'prefix' => $data['yaxis_items'][$data['ymax_itemid']]['hosts'][0]['name'].NAME_DELIMITER
+				]];
+			}
+			else {
+				$ymax_axis_ms_data = [[
+					'id' => $data['ymax_itemid'],
+					'name' => _('Inaccessible item'),
+					'prefix' => ''
+				]];
+			}
 		}
 
 		$yaxisMaxData[] = (new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN);
-		$yaxisMaxData[] = (new CTextBox('ymax_name', $ymax_name, true))
-			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
-			->setAriaRequired();
-		$yaxisMaxData[] = (new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN);
 
-		// Select item button.
-		$yaxisMaxData[] = (new CButton('yaxis_max', _('Select')))
-			->addClass(ZBX_STYLE_BTN_GREY)
-			->onClick('return PopUp("popup.generic",jQuery.extend('.
-				json_encode([
+		$yaxisMaxData[] = (new CMultiSelect([
+			'name' => 'ymax_itemid',
+			'object_name' => 'items',
+			'data' => $ymax_axis_ms_data,
+			'multiple' => false,
+			'disabled' => $readonly,
+			'styles' => [
+				'display' => 'inline-flex'
+			],
+			'popup' => [
+				'parameters' => [
 					'srctbl' => 'items',
 					'srcfld1' => 'itemid',
 					'srcfld2' => 'name',
 					'dstfrm' => $graphForm->getName(),
 					'dstfld1' => 'ymax_itemid',
-					'dstfld2' => 'ymax_name',
-					'with_webitems' => '1',
+					'hostid' => $data['is_template'] ? $data['hostid'] : 0,
 					'numeric' => '1',
-					'writeonly' => '1'
-				]).
-					',getOnlyHostParam()), null, this);'
-			)
-			->setEnabled(!$readonly);
+					'real_hosts' => !$data['is_template']
+				]
+			]
+		]))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH);
 
 		// Select item prototype button.
 		if ($data['parent_discoveryid'] !== null) {
 			$yaxisMaxData[] = (new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN);
 			$yaxisMaxData[] = (new CButton('yaxis_max_prototype', _('Select prototype')))
 				->addClass(ZBX_STYLE_BTN_GREY)
-				->onClick('return PopUp("popup.generic",'.
-					json_encode([
-						'srctbl' => 'item_prototypes',
-						'srcfld1' => 'itemid',
-						'srcfld2' => 'name',
-						'dstfrm' => $graphForm->getName(),
-						'dstfld1' => 'ymax_itemid',
-						'dstfld2' => 'ymax_name',
-						'parent_discoveryid' => $data['parent_discoveryid'],
-						'numeric' => '1'
-					]).', null, this);'
-				)
+				->setAttribute('data-parent_discoveryid', $data['parent_discoveryid'])
+				->onClick('
+					PopUp("popup.generic", {
+						srctbl: "item_prototypes",
+						srcfld1: "itemid",
+						srcfld2: "name",
+						dstfrm: "'.$graphForm->getName().'",
+						dstfld1: "ymax_itemid",
+						parent_discoveryid: this.dataset.parent_discoveryid,
+						numeric: 1
+					}, {dialogue_class: "modal-popup-generic"});
+				')
 				->setEnabled(!$readonly);
 		}
 	}
 	else {
-		$graphForm->addVar('yaxismax', $this->data['yaxismax']);
+		$graphForm->addVar('yaxismax', $data['yaxismax']);
 	}
 
-	$yaxismax_label = new CLabel(_('Y axis MAX value'));
-	if ($this->data['ymax_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
-		$yaxismax_label
-			->setAsteriskMark()
-			->setAttribute('for', 'ymax_name');
+	$yaxismax_label = new CLabel(_('Y axis MAX value'), 'ymax_type_label');
+	if ($data['ymax_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
+		$yaxismax_label->setAsteriskMark();
 	}
 
 	$graphFormList->addRow($yaxismax_label, $yaxisMaxData);
@@ -345,7 +363,7 @@ if ($this->data['graphtype'] == GRAPH_TYPE_NORMAL || $this->data['graphtype'] ==
 else {
 	$graphFormList->addRow(_('3D view'),
 		(new CCheckBox('show_3d'))
-			->setChecked($this->data['show_3d'] == 1)
+			->setChecked($data['show_3d'] == 1)
 			->setEnabled(!$readonly)
 	);
 }
@@ -356,48 +374,47 @@ $items_table = (new CTable())
 	->setColumns([
 		(new CTableColumn())->addClass('table-col-handle'),
 		(new CTableColumn())->addClass('table-col-no'),
-		(new CTableColumn(_('Name')))->addClass(($this->data['graphtype'] == GRAPH_TYPE_NORMAL)
+		(new CTableColumn(_('Name')))->addClass(($data['graphtype'] == GRAPH_TYPE_NORMAL)
 			? 'table-col-name-normal'
 			: 'table-col-name'
 		),
-		in_array($this->data['graphtype'], [GRAPH_TYPE_PIE, GRAPH_TYPE_EXPLODED])
+		in_array($data['graphtype'], [GRAPH_TYPE_PIE, GRAPH_TYPE_EXPLODED])
 			? (new CTableColumn(_('Type')))->addClass('table-col-type')
 			: null,
 		(new CTableColumn(_('Function')))->addClass('table-col-function'),
-		($this->data['graphtype'] == GRAPH_TYPE_NORMAL)
+		($data['graphtype'] == GRAPH_TYPE_NORMAL)
 			? (new CTableColumn(
 				(new CColHeader(_('Draw style')))->addClass(ZBX_STYLE_NOWRAP)
 			))
 				->addClass('table-col-draw-style')
 			: null,
-		in_array($this->data['graphtype'], [GRAPH_TYPE_NORMAL, GRAPH_TYPE_STACKED])
+		in_array($data['graphtype'], [GRAPH_TYPE_NORMAL, GRAPH_TYPE_STACKED])
 			? (new CTableColumn(
 				(new CColHeader(_('Y axis side')))->addClass(ZBX_STYLE_NOWRAP)
 			))
 				->addClass('table-col-y-axis-side')
 			: null,
-		(new CTableColumn(_('Colour')))->addClass('table-col-colour'),
+		(new CTableColumn(_('Color')))->addClass('table-col-colour'),
 		$readonly ? null : (new CTableColumn(_('Action')))->addClass('table-col-action')
 	]);
 
-$popup_options_add = [
+$parameters_add = [
 	'srctbl' => 'items',
 	'srcfld1' => 'itemid',
 	'srcfld2' => 'name',
 	'dstfrm' => $graphForm->getName(),
 	'numeric' => '1',
 	'writeonly' => '1',
-	'multiselect' => '1',
-	'with_webitems' => '1'
+	'multiselect' => '1'
 ];
 if ($data['normal_only']) {
-	$popup_options_add['normal_only'] = '1';
+	$parameters_add['normal_only'] = '1';
 }
 if ($data['hostid']) {
-	$popup_options_add['hostid'] = $data['hostid'];
+	$parameters_add['hostid'] = $data['hostid'];
 }
 
-$popup_options_add_prototype = [
+$parameters_add_prototype = [
 	'srctbl' => 'item_prototypes',
 	'srcfld1' => 'itemid',
 	'srcfld2' => 'name',
@@ -408,10 +425,10 @@ $popup_options_add_prototype = [
 	'graphtype' => $data['graphtype']
 ];
 if ($data['normal_only']) {
-	$popup_options_add_prototype['normal_only'] = '1';
+	$parameters_add_prototype['normal_only'] = '1';
 }
 if ($data['parent_discoveryid']) {
-	$popup_options_add_prototype['parent_discoveryid'] = $data['parent_discoveryid'];
+	$parameters_add_prototype['parent_discoveryid'] = $data['parent_discoveryid'];
 }
 
 $items_table->addRow(
@@ -421,14 +438,20 @@ $items_table->addRow(
 			: (new CCol(
 				new CHorList([
 					(new CButton('add_item', _('Add')))
-						->onClick('return PopUp("popup.generic",jQuery.extend('.
-							json_encode($popup_options_add).',getOnlyHostParam()), null, this);'
+						->setAttribute('data-parameters', json_encode($parameters_add))
+						->onClick(
+							'return PopUp("popup.generic",
+								jQuery.extend(JSON.parse(this.dataset.parameters), view.getOnlyHostParam())
+							);'
 						)
 						->addClass(ZBX_STYLE_BTN_LINK),
 					$data['parent_discoveryid']
 						? (new CButton('add_protoitem', _('Add prototype')))
-							->onClick('return PopUp("popup.generic",'.
-								json_encode($popup_options_add_prototype).', null, this);'
+							->setAttribute('data-parameters', json_encode($parameters_add_prototype))
+							->onClick(
+								'return PopUp("popup.generic", JSON.parse(this.dataset.parameters),
+									{dialogue_class: "modal-popup-generic"}
+								);'
 							)
 							->addClass(ZBX_STYLE_BTN_LINK)
 						: null
@@ -437,28 +460,6 @@ $items_table->addRow(
 	))->setId('itemButtonsRow')
 );
 
-foreach ($this->data['items'] as $n => $item) {
-	$name = $item['host'].NAME_DELIMITER.$item['name_expanded'];
-
-	if (zbx_empty($item['drawtype'])) {
-		$item['drawtype'] = 0;
-	}
-
-	if (zbx_empty($item['yaxisside'])) {
-		$item['yaxisside'] = 0;
-	}
-
-	if (!array_key_exists('gitemid', $item)) {
-		$item['gitemid'] = '';
-	}
-
-	insert_js('loadItem('.$n.', '.json_encode($item['gitemid']).', '.$item['itemid'].', '.
-		json_encode($name).', '.$item['type'].', '.$item['calc_fnc'].', '.$item['drawtype'].', '.
-		$item['yaxisside'].', \''.$item['color'].'\', '.$item['flags'].');',
-		true
-	);
-}
-
 $graphFormList->addRow(
 	(new CLabel(_('Items'), $items_table->getId()))->setAsteriskMark(),
 	(new CDiv($items_table))->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR)
@@ -474,9 +475,12 @@ if ($data['parent_discoveryid']) {
 
 // Append tabs to form.
 $graphTab = (new CTabView())
-	->setSelected(0)
 	->addTab('graphTab', ($data['parent_discoveryid'] === null) ? _('Graph') : _('Graph prototype'), $graphFormList);
 
+if ($data['form_refresh'] == 0) {
+	$graphTab->setSelected(0);
+}
+
 /*
  * Preview tab
  */
@@ -534,3 +538,21 @@ $graphForm->addItem($graphTab);
 $widget->addItem($graphForm);
 
 $widget->show();
+
+(new CScriptTag('
+	view.init('.json_encode([
+		'form_name' => $graphForm->getName(),
+		'theme_colors' => explode(',', getUserGraphTheme()['colorpalette']),
+		'graphs' => [
+			'graphtype' =>  $data['graphtype'],
+			'readonly' => $readonly,
+			'hostid' => $data['hostid'],
+			'is_template' => $data['is_template'],
+			'normal_only' => $data['normal_only'],
+			'parent_discoveryid' => $data['parent_discoveryid']
+		],
+		'items' => $data['items']
+	]).');
+'))
+	->setOnDocumentReady()
+	->show();
