@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -27,23 +27,27 @@ require_once dirname(__FILE__).'/js/configuration.host.discovery.list.js.php';
 
 $widget = (new CWidget())
 	->setTitle(_('Discovery rules'))
+	->setDocUrl(CDocHelper::getUrl($data['context'] === 'host'
+		? CDocHelper::CONFIGURATION_HOST_DISCOVERY_LIST
+		: CDocHelper::CONFIGURATION_TEMPLATES_DISCOVERY_LIST
+	))
 	->setControls(
 		(new CTag('nav', true,
-			(new CList())->addItem(
-				($data['hostid'] != 0)
-					? new CRedirectButton(_('Create discovery rule'),
-						(new CUrl('host_discovery.php'))
-							->setArgument('form', 'create')
-							->setArgument('hostid', $data['hostid'])
-							->setArgument('context', $data['context'])
-							->getUrl()
-					)
-					: (new CButton('form',
-						($data['context'] === 'host')
-							? _('Create discovery rule (select host first)')
-							: _('Create discovery rule (select template first)')
-					))->setEnabled(false)
-			)
+			(new CList())
+				->addItem(
+					$data['hostid'] != 0
+						? new CRedirectButton(_('Create discovery rule'),
+							(new CUrl('host_discovery.php'))
+								->setArgument('form', 'create')
+								->setArgument('hostid', $data['hostid'])
+								->setArgument('context', $data['context'])
+						)
+						: (new CButton('form',
+							$data['context'] === 'host'
+								? _('Create discovery rule (select host first)')
+								: _('Create discovery rule (select template first)')
+						))->setEnabled(false)
+				)
 		))->setAttribute('aria-label', _('Content controls'))
 	);
 
@@ -52,24 +56,26 @@ if ($data['hostid'] != 0) {
 }
 
 // Add filter tab.
-$filter = (new CFilter((new CUrl('host_discovery.php'))->setArgument('context', $data['context'])))
+$filter = (new CFilter())
+	->setResetUrl((new CUrl('host_discovery.php'))->setArgument('context', $data['context']))
 	->setProfile($data['profileIdx'])
 	->setActiveTab($data['active_tab'])
 	->addvar('context', $data['context']);
 
-$hg_ms_params = ($data['context'] === 'host') ? ['real_hosts' => 1] : ['templated_hosts' => 1];
+$hg_ms_params = $data['context'] === 'host' ? ['with_hosts' => true] : ['with_templates' => true];
 
 $filter_column1 = (new CFormList())
-	->addRow((new CLabel(_('Host groups'), 'filter_groupids__ms')),
+	->addRow(
+		new CLabel($data['context'] === 'host' ? _('Host groups') : _('Template groups'), 'filter_groupids__ms'),
 		(new CMultiSelect([
 			'name' => 'filter_groupids[]',
-			'object_name' => 'hostGroup',
+			'object_name' => $data['context'] === 'host' ? 'hostGroup' : 'templateGroup',
 			'data' => $data['filter']['groups'],
 			'popup' => [
 				'parameters' => [
-					'srctbl' => 'host_groups',
+					'srctbl' => $data['context'] === 'host' ? 'host_groups' : 'template_groups',
 					'srcfld1' => 'groupid',
-					'dstfrm' => $filter->getName(),
+					'dstfrm' => 'zbx_filter',
 					'dstfld1' => 'filter_groupids_',
 					'editable' => true,
 					'enrich_parent_groups' => true
@@ -77,19 +83,20 @@ $filter_column1 = (new CFormList())
 			]
 		]))->setWidth(ZBX_TEXTAREA_FILTER_STANDARD_WIDTH)
 	)
-	->addRow((new CLabel(($data['context'] === 'host') ? _('Hosts') : _('Templates'), 'filter_hostids__ms')),
+	->addRow(
+		new CLabel($data['context'] === 'host' ? _('Hosts') : _('Templates'), 'filter_hostids__ms'),
 		(new CMultiSelect([
 			'name' => 'filter_hostids[]',
-			'object_name' => ($data['context'] === 'host') ? 'hosts' : 'templates',
+			'object_name' => $data['context'] === 'host' ? 'hosts' : 'templates',
 			'data' => $data['filter']['hosts'],
 			'popup' => [
-				'filter_preselect_fields' => [
-					'hostgroups' => 'filter_groupids_'
-				],
+				'filter_preselect_fields' => $data['context'] === 'host'
+					? ['hostgroups' => 'filter_groupids_']
+					: ['templategroups' => 'filter_groupids_'],
 				'parameters' => [
-					'srctbl' => ($data['context'] === 'host') ? 'hosts' : 'templates',
+					'srctbl' => $data['context'] === 'host' ? 'hosts' : 'templates',
 					'srcfld1' => 'hostid',
-					'dstfrm' => $filter->getName(),
+					'dstfrm' => 'zbx_filter',
 					'dstfld1' => 'filter_hostids_',
 					'editable' => true
 				]
@@ -212,10 +219,10 @@ foreach ($data['discoveries'] as $discovery) {
 
 	if ($discovery['type'] == ITEM_TYPE_DEPENDENT) {
 		if ($discovery['master_item']['type'] == ITEM_TYPE_HTTPTEST) {
-			$description[] = CHtml::encode($discovery['master_item']['name_expanded']);
+			$description[] = CHtml::encode($discovery['master_item']['name']);
 		}
 		else {
-			$description[] = (new CLink(CHtml::encode($discovery['master_item']['name_expanded']),
+			$description[] = (new CLink(CHtml::encode($discovery['master_item']['name']),
 				(new CUrl('items.php'))
 					->setArgument('form', 'update')
 					->setArgument('itemid', $discovery['master_item']['itemid'])
@@ -230,7 +237,7 @@ foreach ($data['discoveries'] as $discovery) {
 	}
 
 	$description[] = new CLink(
-		CHtml::encode($discovery['name_expanded']),
+		CHtml::encode($discovery['name']),
 		(new CUrl('host_discovery.php'))
 			->setArgument('form', 'update')
 			->setArgument('itemid', $discovery['itemid'])
@@ -273,8 +280,16 @@ foreach ($data['discoveries'] as $discovery) {
 		}
 	}
 
+	$checkbox = new CCheckBox('g_hostdruleid['.$discovery['itemid'].']', $discovery['itemid']);
+
+	if (in_array($discovery['type'], checkNowAllowedTypes())
+			&& $discovery['status'] == ITEM_STATUS_ACTIVE
+			&& $discovery['hosts'][0]['status'] == HOST_STATUS_MONITORED) {
+		$checkbox->setAttribute('data-actions', 'execute');
+	}
+
 	$discoveryTable->addRow([
-		new CCheckBox('g_hostdruleid['.$discovery['itemid'].']', $discovery['itemid']),
+		$checkbox,
 		$discovery['hosts'][0]['name'],
 		$description,
 		[
@@ -325,7 +340,15 @@ $button_list = [
 ];
 
 if ($data['context'] === 'host') {
-	$button_list += ['discoveryrule.masscheck_now' => ['name' => _('Execute now'), 'disabled' => $data['is_template']]];
+	$button_list += [
+		'discoveryrule.masscheck_now' => [
+			'content' => (new CSimpleButton(_('Execute now')))
+				->onClick('view.massCheckNow(this);')
+				->addClass(ZBX_STYLE_BTN_ALT)
+				->addClass('no-chkbxrange')
+				->setAttribute('data-required', 'execute')
+		]
+	];
 }
 
 $button_list += [
@@ -341,3 +364,12 @@ $discoveryForm->addItem([$discoveryTable, $data['paging'], new CActionButtonList
 $widget->addItem($discoveryForm);
 
 $widget->show();
+
+(new CScriptTag('
+	view.init('.json_encode([
+		'checkbox_hash' => $data['checkbox_hash'],
+		'checkbox_object' => 'g_hostdruleid'
+	]).');
+'))
+	->setOnDocumentReady()
+	->show();
