@@ -1,4 +1,28 @@
 <?php
+/*
+** Zabbix
+** Copyright (C) 2001-2023 Zabbix SIA
+**
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program; if not, write to the Free Software
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+**/
+
+
+/**
+ * @var CView $this
+ */
+
 $shape_border_types = [
 	SYSMAP_SHAPE_BORDER_TYPE_NONE		=> _('None'),
 	SYSMAP_SHAPE_BORDER_TYPE_SOLID		=> '———',
@@ -8,7 +32,7 @@ $shape_border_types = [
 
 $horizontal_align_types = [
 	SYSMAP_SHAPE_LABEL_HALIGN_LEFT		=> _('Left'),
-	SYSMAP_SHAPE_LABEL_HALIGN_CENTER	=> _('Centre'),
+	SYSMAP_SHAPE_LABEL_HALIGN_CENTER	=> _('Center'),
 	SYSMAP_SHAPE_LABEL_HALIGN_RIGHT		=> _('Right')
 ];
 
@@ -19,41 +43,45 @@ $vertical_align_types = [
 ];
 
 /**
- * Get font selection for Combobox.
+ * Get font select element.
  *
- * @param string $name				Combobox name.
+ * @param string $name
  *
- * @return CComboBox
+ * @return CSelect
  */
-function getFontComboBox($name) {
-	return (new CComboBox($name))
-		->addItem(
-			(new COptGroup(_('Serif')))
-				->addItem(new CComboItem(0, 'Georgia'))
-				->addItem(new CComboItem(1, 'Palatino'))
-				->addItem(new CComboItem(2, 'Times New Roman'))
-		)
-		->addItem(
-			(new COptGroup(_('Sans-Serif')))
-				->addItem(new CComboItem(3, 'Arial'))
-				->addItem(new CComboItem(4, 'Arial Black'))
-				->addItem(new CComboItem(5, 'Comic Sans'))
-				->addItem(new CComboItem(6, 'Impact'))
-				->addItem(new CComboItem(7, 'Lucida Sans'))
-				->addItem(new CComboItem(8, 'Tahoma'))
-				->addItem(new CComboItem(9, 'Helvetica'))
-				->addItem(new CComboItem(10, 'Verdana'))
-		)
-		->addItem(
-			(new COptGroup(_('Monospace')))
-				->addItem(new CComboItem(11, 'Courier New'))
-				->addItem(new CComboItem(12, 'Lucida Console'))
-		);
+function createFontSelect(string $name): CSelect {
+	return (new CSelect($name))
+		->setId($name)
+		->addOptionGroup((new CSelectOptionGroup(_('Serif')))->addOptions(CSelect::createOptionsFromArray([
+			0 => 'Georgia',
+			1 => 'Palatino',
+			2 => 'Times New Roman'
+		])))
+		->addOptionGroup((new CSelectOptionGroup(_('Sans-Serif')))->addOptions(CSelect::createOptionsFromArray([
+			3 => 'Arial',
+			4 => 'Arial Black',
+			5 => 'Comic Sans',
+			6 => 'Impact',
+			7 => 'Lucida Sans',
+			8 => 'Tahoma',
+			9 => 'Helvetica',
+			10 => 'Verdana'
+		])))
+		->addOptionGroup((new CSelectOptionGroup(_('Monospace')))->addOptions(CSelect::createOptionsFromArray([
+			11 => 'Courier New',
+			12 => 'Lucida Console'
+		])));
 }
 ?>
 <script type="text/x-jquery-tmpl" id="mapElementFormTpl">
-	<?= (new CDiv(new CTag('h4', true, _('Map element'))))
-			->addClass(ZBX_STYLE_DASHBRD_WIDGET_HEAD)
+	<?= (new CDiv([
+			(new CTag('h4', true, _('Map element'))),
+			(new CLink(null, CDocHelper::getUrl(CDocHelper::POPUP_MAP_ELEMENT)))
+				->setTitle(_('Help'))
+				->addClass(ZBX_STYLE_ICON_DOC_LINK)
+				->setTarget('_blank')
+		]))
+			->addClass(ZBX_STYLE_DASHBOARD_WIDGET_HEAD)
 			->setId('formDragHandler')
 			->toString()
 	?>
@@ -63,14 +91,17 @@ function getFontComboBox($name) {
 			->setId('selementForm')
 			->addItem(
 				(new CFormList())
-					->addRow(_('Type'),
-						(new CComboBox('elementtype', null, null, [
-							SYSMAP_ELEMENT_TYPE_HOST => _('Host'),
-							SYSMAP_ELEMENT_TYPE_MAP => _('Map'),
-							SYSMAP_ELEMENT_TYPE_TRIGGER => _('Trigger'),
-							SYSMAP_ELEMENT_TYPE_HOST_GROUP => _('Host group'),
-							SYSMAP_ELEMENT_TYPE_IMAGE => _('Image')
-						]))->setId('elementType')
+					->addRow(new CLabel(_('Type'), 'label-elementtype'),
+						(new CSelect('elementtype'))
+							->setFocusableElementId('label-elementtype')
+							->addOptions(CSelect::createOptionsFromArray([
+								SYSMAP_ELEMENT_TYPE_HOST => _('Host'),
+								SYSMAP_ELEMENT_TYPE_MAP => _('Map'),
+								SYSMAP_ELEMENT_TYPE_TRIGGER => _('Trigger'),
+								SYSMAP_ELEMENT_TYPE_HOST_GROUP => _('Host group'),
+								SYSMAP_ELEMENT_TYPE_IMAGE => _('Image')
+							]))
+							->setId('elementType')
 					)
 					->addRow(_('Show'),
 						(new CRadioButtonList('elementsubtype', SYSMAP_ELEMENT_SUBTYPE_HOST_GROUP))
@@ -102,7 +133,7 @@ function getFontComboBox($name) {
 							->setId('areaSizeHeight')
 					], 'areaSizeRow')
 					->addRow(_('Placing algorithm'),
-						(new CRadioButtonList(null, SYSMAP_ELEMENT_AREA_VIEWTYPE_GRID))
+						(new CRadioButtonList('viewtype', SYSMAP_ELEMENT_AREA_VIEWTYPE_GRID))
 							->addValue(_('Grid'), SYSMAP_ELEMENT_AREA_VIEWTYPE_GRID)
 							->setModern(true),
 						'areaPlacingRow'
@@ -113,14 +144,16 @@ function getFontComboBox($name) {
 							->setRows(2)
 							->setId('elementLabel')
 					)
-					->addRow(_('Label location'),
-						new CComboBox('label_location', null, null, [
-							MAP_LABEL_LOC_DEFAULT => _('Default'),
-							MAP_LABEL_LOC_BOTTOM => _('Bottom'),
-							MAP_LABEL_LOC_LEFT => _('Left'),
-							MAP_LABEL_LOC_RIGHT => _('Right'),
-							MAP_LABEL_LOC_TOP => _('Top')
-						])
+					->addRow(new CLabel(_('Label location'), 'label-label-location'),
+						(new CSelect('label_location'))
+							->setFocusableElementId('label-label-location')
+							->addOptions(CSelect::createOptionsFromArray([
+								MAP_LABEL_LOC_DEFAULT => _('Default'),
+								MAP_LABEL_LOC_BOTTOM => _('Bottom'),
+								MAP_LABEL_LOC_LEFT => _('Left'),
+								MAP_LABEL_LOC_RIGHT => _('Right'),
+								MAP_LABEL_LOC_TOP => _('Top')
+							]))
 					)
 					->addRow((new CLabel(_('Host group'), 'elementNameHostGroup_ms'))->setAsteriskMark(),
 						(new CMultiSelect([
@@ -163,8 +196,7 @@ function getFontComboBox($name) {
 										'dstfrm' => 'selementForm',
 										'dstfld1' => 'elementNameTriggers',
 										'with_triggers' => true,
-										'editable' => true,
-										'noempty' => true,
+										'editable' => 1,
 										'real_hosts' => true
 									]
 								]
@@ -188,27 +220,42 @@ function getFontComboBox($name) {
 						(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
 						(new CButton(null, _('Select')))
 							->addClass(ZBX_STYLE_BTN_GREY)
-							->onClick('return PopUp("popup.generic",jQuery.extend('.
-								CJs::encodeJson([
+							->onClick(
+								'return PopUp("popup.generic", jQuery.extend('.json_encode([
 									'srctbl' => 'sysmaps',
 									'srcfld1' => 'sysmapid',
 									'srcfld2' => 'name',
 									'dstfrm' => 'selementForm',
 									'dstfld1' => 'sysmapid',
 									'dstfld2' => 'elementNameMap'
-								]).
-									',{excludeids: [#{sysmapid}]}), null, this);'
+								]).', {excludeids: [#{sysmapid}]}), {dialogue_class: "modal-popup-generic"});'
 							)
 					], 'mapSelectRow')
-					->addRow(_('Application'), [
-						(new CTextBox('application'))
-							->setId('application')
-							->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH),
-						(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-						(new CButton(null, _('Select')))
-							->setId('application-select')
-							->addClass(ZBX_STYLE_BTN_GREY)
-					], 'application-select-row')
+					->addRow(_('Tags'),
+						(new CDiv([
+							(new CTable())
+								->setId('selement-tags')
+								->addRow(
+									(new CCol(
+										(new CRadioButtonList('evaltype', TAG_EVAL_TYPE_AND_OR))
+											->addValue(_('And/Or'), TAG_EVAL_TYPE_AND_OR)
+											->addValue(_('Or'), TAG_EVAL_TYPE_OR)
+											->setModern(true)
+									))->setColSpan(4)
+								)
+								->addRow(
+									(new CCol(
+										(new CButton('tags_add', _('Add')))
+											->addClass(ZBX_STYLE_BTN_LINK)
+											->addClass('element-table-add')
+											->removeId()
+									))->setColSpan(3)
+								)
+						]))
+							->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR)
+							->setAttribute('style', 'min-width: '.ZBX_TEXTAREA_BIG_WIDTH.'px;'),
+						'tags-select-row'
+					)
 					->addRow(_('Automatic icon selection'),
 						new CCheckBox('use_iconmap'),
 						'useIconMapRow'
@@ -216,21 +263,39 @@ function getFontComboBox($name) {
 					->addRow(_('Icons'),
 						(new CDiv(
 							(new CTable())
-								->addRow([new CLabel(_('Default'), 'iconid_off'), new CComboBox('iconid_off')])
+								->addRow([
+									new CLabel(_('Default'), 'label-iconid-off'),
+									(new CSelect('iconid_off'))
+										->setId('iconid_off')
+										->setFocusableElementId('label-iconid-off')
+										->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
+								])
 								->addRow(
-									(new CRow([new CLabel(_('Problem'), 'iconid_on'), new CComboBox('iconid_on')]))
+									(new CRow([
+										new CLabel(_('Problem'), 'label-iconid-on'),
+										(new CSelect('iconid_on'))
+											->setId('iconid_on')
+											->setFocusableElementId('label-iconid-on')
+											->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
+									]))
 										->setId('iconProblemRow')
 								)
 								->addRow(
 									(new CRow([
-										new CLabel(_('Maintenance'), 'iconid_maintenance'),
-										new CComboBox('iconid_maintenance')
+										new CLabel(_('Maintenance'), 'label-iconid-maintenance'),
+										(new CSelect('iconid_maintenance'))
+											->setId('iconid_maintenance')
+											->setFocusableElementId('label-iconid-maintenance')
+											->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
 									]))->setId('iconMainetnanceRow')
 								)
 								->addRow(
 									(new CRow([
-										new CLabel(_('Disabled'), 'iconid_disabled'),
-										new CComboBox('iconid_disabled')
+										new CLabel(_('Disabled'), 'label-iconid-disabled'),
+										(new CSelect('iconid_disabled'))
+											->setId('iconid_disabled')
+											->setFocusableElementId('label-iconid-disabled')
+											->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
 									]))->setId('iconDisabledRow')
 								)
 								->setAttribute('style', 'width: 100%;')
@@ -246,7 +311,7 @@ function getFontComboBox($name) {
 						_('Y'),
 						(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
 						(new CTextBox('y'))->setWidth(ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH)
-					], 'areaSizeRow')
+					])
 					->addRow(_('URLs'),
 						(new CDiv([
 							(new CTable())
@@ -283,8 +348,14 @@ function getFontComboBox($name) {
 </script>
 
 <script type="text/x-jquery-tmpl" id="mapShapeFormTpl">
-	<?= (new CDiv(new CTag('h4', true, _('Map shape'))))
-			->addClass(ZBX_STYLE_DASHBRD_WIDGET_HEAD)
+	<?= (new CDiv([
+			(new CTag('h4', true, _('Map shape'))),
+			(new CLink(null, CDocHelper::getUrl(CDocHelper::POPUP_MAP_SHAPE)))
+				->setTitle(_('Help'))
+				->addClass(ZBX_STYLE_ICON_DOC_LINK)
+				->setTarget('_blank')
+		]))
+			->addClass(ZBX_STYLE_DASHBOARD_WIDGET_HEAD)
 			->setId('shapeDragHandler')
 			->toString().
 		(new CForm())
@@ -311,36 +382,36 @@ function getFontComboBox($name) {
 							BR(),
 							_('Font'),
 							(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-							getFontComboBox('font'),
+							createFontSelect('font'),
 							(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
 							_('Font size'),
 							(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
 							(new CTextBox('font_size'))->setWidth(ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH),
 							(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-							_('Colour'),
+							_('Color'),
 							(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
 							(new CColor('font_color', '#{color}'))->appendColorPickerJs(false),
 							BR(),
 							_('Horizontal align'),
 							(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-							(new CComboBox('text_halign', SYSMAP_SHAPE_LABEL_HALIGN_CENTER, null,
-								$horizontal_align_types
-							))
+							(new CSelect('text_halign'))
+								->setValue(SYSMAP_SHAPE_LABEL_HALIGN_CENTER)
+								->addOptions(CSelect::createOptionsFromArray($horizontal_align_types))
 								->setAttribute('style', 'margin-top: 4px'),
 							(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
 							_('Vertical align'),
 							(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-							(new CComboBox('text_valign', SYSMAP_SHAPE_LABEL_VALIGN_MIDDLE, null,
-								$vertical_align_types
-							))
+							(new CSelect('text_valign'))
+								->setValue(SYSMAP_SHAPE_LABEL_VALIGN_MIDDLE)
+								->addOptions(CSelect::createOptionsFromArray($vertical_align_types))
 						]))->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR),
 						'shape-text-row'
 					)
 					->addRow(_('Background'),
 						(new CDiv([
-							_('Colour'),
+							_('Color'),
 							(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-							(new CColor('background_color', '#{color}'))->appendColorPickerJs(false),
+							(new CColor('background_color', '#{color}'))->appendColorPickerJs(false)
 						]))->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR),
 						'shape-background-row'
 					)
@@ -351,15 +422,16 @@ function getFontComboBox($name) {
 						(new CDiv([
 							_('Type'),
 							(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-							(new CComboBox('border_type', null, null, $shape_border_types)),
+							(new CSelect('border_type'))
+								->addOptions(CSelect::createOptionsFromArray($shape_border_types)),
 							(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
 							_('Width'),
 							(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
 							(new CTextBox('border_width'))->setWidth(ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH),
 							(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-							_('Colour'),
+							_('Color'),
 							(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-							(new CColor('border_color', '#{color}'))->appendColorPickerJs(false),
+							(new CColor('border_color', '#{color}'))->appendColorPickerJs(false)
 						]))
 							->addClass(ZBX_STYLE_NOWRAP)
 							->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR)
@@ -374,14 +446,18 @@ function getFontComboBox($name) {
 								->setAttribute('data-value', _('X'))
 								->setAttribute('data-value-2', _('X1')),
 							(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-							(new CTextBox('x'))->setWidth(ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH),
+							(new CTextBox('x'))
+								->setWidth(ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH)
+								->setId('shapeX'),
 							(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
 							(new CSpan())
 								->addClass('switchable-content')
 								->setAttribute('data-value', _('Y'))
 								->setAttribute('data-value-2', _('Y1')),
 							(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-							(new CTextBox('y'))->setWidth(ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH)
+							(new CTextBox('y'))
+								->setWidth(ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH)
+								->setId('shapeY')
 						]))->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR)
 					)
 					->addRow((new CSpan())
@@ -396,7 +472,7 @@ function getFontComboBox($name) {
 							(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
 							(new CTextBox('width'))
 								->setWidth(ZBX_TEXTAREA_TINY_WIDTH)
-								->setId('areaSizeWidth'),
+								->setId('shapeAreaSizeWidth'),
 							(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
 							(new CSpan())
 								->addClass('switchable-content')
@@ -405,7 +481,7 @@ function getFontComboBox($name) {
 							(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
 							(new CTextBox('height'))
 								->setWidth(ZBX_TEXTAREA_TINY_WIDTH)
-								->setId('areaSizeHeight')
+								->setId('shapeAreaSizeHeight')
 						]))->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR)
 					)
 					->addItem([
@@ -431,8 +507,14 @@ function getFontComboBox($name) {
 </script>
 
 <script type="text/x-jquery-tmpl" id="mapMassShapeFormTpl">
-	<?= (new CDiv(new CTag('h4', true, _('Mass update shapes'))))
-			->addClass(ZBX_STYLE_DASHBRD_WIDGET_HEAD)
+	<?= (new CDiv([
+			(new CTag('h4', true, _('Mass update shapes'))),
+			(new CLink(null, CDocHelper::getUrl(CDocHelper::POPUP_MAP_MASSUPDATE_SHAPES)))
+				->setTitle(_('Help'))
+				->addClass(ZBX_STYLE_ICON_DOC_LINK)
+				->setTarget('_blank')
+		]))
+			->addClass(ZBX_STYLE_DASHBOARD_WIDGET_HEAD)
 			->setId('massShapeDragHandler')
 			->toString().
 		(new CForm())
@@ -461,7 +543,7 @@ function getFontComboBox($name) {
 					->addRow((new CCheckBox('chkbox_font'))
 							->setId('chkboxFont')
 							->setLabel(_('Font')),
-						getFontComboBox('mass_font'),
+						createFontSelect('mass_font'),
 						null, 'shape_figure_row'
 					)
 					->addRow((new CCheckBox('chkbox_font_size'))
@@ -472,29 +554,31 @@ function getFontComboBox($name) {
 					)
 					->addRow((new CCheckBox('chkbox_font_color'))
 							->setId('chkboxFontColor')
-							->setLabel(_('Font colour')),
+							->setLabel(_('Font color')),
 						(new CColor('mass_font_color', '#{color}'))->appendColorPickerJs(false),
 						null, 'shape_figure_row'
 					)
 					->addRow((new CCheckBox('chkbox_text_halign'))
 							->setId('chkboxTextHalign')
 							->setLabel(_('Horizontal align')),
-						new CComboBox('mass_text_halign', SYSMAP_SHAPE_LABEL_HALIGN_CENTER, null,
-							$horizontal_align_types
-						),
+						(new CSelect('mass_text_halign'))
+							->setId('mass_text_halign')
+							->setValue(SYSMAP_SHAPE_LABEL_HALIGN_CENTER)
+							->addOptions(CSelect::createOptionsFromArray($horizontal_align_types)),
 						null, 'shape_figure_row'
 					)
 					->addRow((new CCheckBox('chkbox_text_valign'))
 							->setId('chkboxTextValign')
 							->setLabel(_('Vertical align')),
-						new CComboBox('mass_text_valign', SYSMAP_SHAPE_LABEL_VALIGN_MIDDLE, null,
-							$vertical_align_types
-						),
+						(new CSelect('mass_text_valign'))
+							->setId('mass_text_valign')
+							->setValue(SYSMAP_SHAPE_LABEL_VALIGN_MIDDLE)
+							->addOptions(CSelect::createOptionsFromArray($vertical_align_types)),
 						null, 'shape_figure_row'
 					)
 					->addRow((new CCheckBox('chkbox_background'))
 							->setId('chkboxBackground')
-							->setLabel(_('Background colour')),
+							->setLabel(_('Background color')),
 						(new CColor('mass_background_color', '#{color}'))->appendColorPickerJs(false),
 						null, 'shape_figure_row'
 					)
@@ -506,7 +590,9 @@ function getFontComboBox($name) {
 								->setAttribute('data-value', _('Border type'))
 								->setAttribute('data-value-2', _('Line type'))
 							),
-						new CComboBox('mass_border_type', null, null, $shape_border_types)
+						(new CSelect('mass_border_type'))
+							->setId('mass_border_type')
+							->addOptions(CSelect::createOptionsFromArray($shape_border_types))
 					)
 					->addRow((new CCheckBox('chkbox_border_width'))
 							->setId('chkboxBorderWidth')
@@ -523,8 +609,8 @@ function getFontComboBox($name) {
 							->setLabel((new CDiv())
 								->addClass('form-input-margin')
 								->addClass('switchable-content')
-								->setAttribute('data-value', _('Border colour'))
-								->setAttribute('data-value-2', _('Line colour'))
+								->setAttribute('data-value', _('Border color'))
+								->setAttribute('data-value-2', _('Line color'))
 							),
 						(new CColor('mass_border_color', '#{color}'))->appendColorPickerJs(false)
 					)
@@ -551,8 +637,14 @@ function getFontComboBox($name) {
 </script>
 
 <script type="text/x-jquery-tmpl" id="mapMassFormTpl">
-	<?= (new CDiv(new CTag('h4', true, _('Mass update elements'))))
-			->addClass(ZBX_STYLE_DASHBRD_WIDGET_HEAD)
+	<?= (new CDiv([
+			(new CTag('h4', true, _('Mass update elements'))),
+			(new CLink(null, CDocHelper::getUrl(CDocHelper::POPUP_MAP_MASSUPDATE_ELEMENTS)))
+				->setTitle(_('Help'))
+				->addClass(ZBX_STYLE_ICON_DOC_LINK)
+				->setTarget('_blank')
+		]))
+			->addClass(ZBX_STYLE_DASHBOARD_WIDGET_HEAD)
 			->setId('massDragHandler')
 			->toString()
 	?>
@@ -584,13 +676,15 @@ function getFontComboBox($name) {
 						(new CCheckBox('chkbox_label_location'))
 							->setId('chkboxLabelLocation')
 							->setLabel(_('Label location')),
-						(new CComboBox('label_location', null, null, [
-							MAP_LABEL_LOC_DEFAULT => _('Default'),
-							MAP_LABEL_LOC_BOTTOM => _('Bottom'),
-							MAP_LABEL_LOC_LEFT => _('Left'),
-							MAP_LABEL_LOC_RIGHT => _('Right'),
-							MAP_LABEL_LOC_TOP => _('Top')
-						]))->setId('massLabelLocation')
+						(new CSelect('label_location'))
+							->addOptions(CSelect::createOptionsFromArray([
+								MAP_LABEL_LOC_DEFAULT => _('Default'),
+								MAP_LABEL_LOC_BOTTOM => _('Bottom'),
+								MAP_LABEL_LOC_LEFT => _('Left'),
+								MAP_LABEL_LOC_RIGHT => _('Right'),
+								MAP_LABEL_LOC_TOP => _('Top')
+							]))
+							->setId('massLabelLocation')
 					)
 					->addRow(
 						(new CCheckBox('chkbox_use_iconmap'))
@@ -603,25 +697,33 @@ function getFontComboBox($name) {
 						(new CCheckBox('chkbox_iconid_off'))
 							->setId('chkboxMassIconidOff')
 							->setLabel(_('Icon (default)')),
-						(new CComboBox('iconid_off'))->setId('massIconidOff')
+						(new CSelect('iconid_off'))
+							->setId('massIconidOff')
+							->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
 					)
 					->addRow(
 						(new CCheckBox('chkbox_iconid_on'))
 							->setId('chkboxMassIconidOn')
 							->setLabel(_('Icon (problem)')),
-						(new CComboBox('iconid_on'))->setId('massIconidOn')
+						(new CSelect('iconid_on'))
+							->setId('massIconidOn')
+							->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
 					)
 					->addRow(
 						(new CCheckBox('chkbox_iconid_maintenance'))
 							->setId('chkboxMassIconidMaintenance')
 							->setLabel(_('Icon (maintenance)')),
-						(new CComboBox('iconid_maintenance'))->setId('massIconidMaintenance')
+						(new CSelect('iconid_maintenance'))
+							->setId('massIconidMaintenance')
+							->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
 					)
 					->addRow(
 						(new CCheckBox('chkbox_iconid_disabled'))
 							->setId('chkboxMassIconidDisabled')
 							->setLabel(_('Icon (disabled)')),
-						(new CComboBox('iconid_disabled'))->setId('massIconidDisabled')
+						(new CSelect('iconid_disabled'))
+							->setId('massIconidDisabled')
+							->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
 					)
 					->addItem([
 						(new CDiv())->addClass(ZBX_STYLE_TABLE_FORMS_TD_LEFT),
@@ -688,36 +790,41 @@ function getFontComboBox($name) {
 							->setRows(2)
 							->setId('linklabel')
 					)
-					->addRow(_('Connect to'), (new CComboBox('selementid2')), 'link-connect-to')
-					->addRow(_('Type (OK)'),
-						(new CComboBox('drawtype', null, null, [
-							GRAPH_ITEM_DRAWTYPE_LINE => _('Line'),
-							GRAPH_ITEM_DRAWTYPE_BOLD_LINE => _('Bold line'),
-							GRAPH_ITEM_DRAWTYPE_DOT => _('Dot'),
-							GRAPH_ITEM_DRAWTYPE_DASHED_LINE => _('Dashed line')
-						]))
+					->addRow(new CLabel(_('Connect to'), 'label-selementid2'), (new CSelect('selementid2'))
+							->setFocusableElementId('label-selementid2')
+							->setId('selementid2'),
+						'link-connect-to'
 					)
-					->addRow(_('Colour (OK)'),
+					->addRow(new CLabel(_('Type (OK)'), 'label-drawtype'),
+						(new CSelect('drawtype'))
+							->setFocusableElementId('label-drawtype')
+							->addOptions(CSelect::createOptionsFromArray([
+								GRAPH_ITEM_DRAWTYPE_LINE => _('Line'),
+								GRAPH_ITEM_DRAWTYPE_BOLD_LINE => _('Bold line'),
+								GRAPH_ITEM_DRAWTYPE_DOT => _('Dot'),
+								GRAPH_ITEM_DRAWTYPE_DASHED_LINE => _('Dashed line')
+							]))
+					)
+					->addRow(_('Color (OK)'),
 						(new CColor('color', '#{color}'))->appendColorPickerJs(false)
 					)
 					->addRow(_('Link indicators'),
 						(new CDiv([
 							(new CTable())
-								->setHeader([_('Trigger'), _('Type'), _('Colour'), _('Action')])
+								->setHeader([_('Trigger'), _('Type'), _('Color'), _('Action')])
 								->setAttribute('style', 'width: 100%;')
 								->setId('linkTriggerscontainer'),
 							(new CButton(null, _('Add')))
 								->addClass(ZBX_STYLE_BTN_LINK)
-								->onClick('return PopUp("popup.generic",'.
-									CJs::encodeJson([
+								->onClick(
+									'return PopUp("popup.generic", '.json_encode([
 										'srctbl' => 'triggers',
 										'srcfld1' => 'triggerid',
 										'reference' => 'linktrigger',
 										'multiselect' => '1',
 										'real_hosts' => '1',
-										'with_triggers' => '1',
-										'noempty' => '1'
-									]).', null, this);'
+										'with_triggers' => '1'
+									]).', {dialogue_class: "modal-popup-generic"});'
 								)
 						]))
 							->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR)
@@ -778,12 +885,14 @@ function getFontComboBox($name) {
 				new CVar('linktrigger_#{linktriggerid}_desc_exp', '#{desc_exp}'),
 				new CVar('linktrigger_#{linktriggerid}_triggerid', '#{triggerid}'),
 				new CVar('linktrigger_#{linktriggerid}_linktriggerid', '#{linktriggerid}'),
-				(new CComboBox('linktrigger_#{linktriggerid}_drawtype', null, null, [
-					GRAPH_ITEM_DRAWTYPE_LINE => _('Line'),
-					GRAPH_ITEM_DRAWTYPE_BOLD_LINE => _('Bold line'),
-					GRAPH_ITEM_DRAWTYPE_DOT => _('Dot'),
-					GRAPH_ITEM_DRAWTYPE_DASHED_LINE => _('Dashed line')
-				]))
+				(new CSelect('linktrigger_#{linktriggerid}_drawtype'))
+					->setId('linktrigger_#{linktriggerid}_drawtype')
+					->addOptions(CSelect::createOptionsFromArray([
+						GRAPH_ITEM_DRAWTYPE_LINE => _('Line'),
+						GRAPH_ITEM_DRAWTYPE_BOLD_LINE => _('Bold line'),
+						GRAPH_ITEM_DRAWTYPE_DOT => _('Dot'),
+						GRAPH_ITEM_DRAWTYPE_DASHED_LINE => _('Dashed line')
+					]))
 			],
 			(new CColor('linktrigger_#{linktriggerid}_color', '#{color}'))->appendColorPickerJs(false),
 			(new CCol(
@@ -813,16 +922,17 @@ function getFontComboBox($name) {
 	?>
 </script>
 
+<script type="text/x-jquery-tmpl" id="tag-row-tmpl">
+	<?= CTagFilterFieldHelper::getTemplate(['tag_field_name' => 'tags']); ?>
+</script>
+
 <script type="text/x-jquery-tmpl" id="selementFormTriggers">
 	<?= (new CRow([
 			(new CCol([
-				(new CDiv())
-					->addClass(ZBX_STYLE_DRAG_ICON)
-					->addStyle('top: 0px;'),
+				(new CDiv())->addClass(ZBX_STYLE_DRAG_ICON),
 				(new CSpan())->addClass('ui-icon ui-icon-arrowthick-2-n-s move '.ZBX_STYLE_TD_DRAG_ICON)
 			]))->addClass(ZBX_STYLE_TD_DRAG_ICON),
 			(new CCol([(new CDiv('#{name}'))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)]))
-				->addStyle('padding: 0 5px;')
 				->addClass('#{class_name}'),
 			(new CCol([
 				(new CVar('element_id[#{triggerid}]', '#{triggerid}')),
@@ -845,10 +955,7 @@ function getFontComboBox($name) {
 	 * @see init.js add.popup event
 	 */
 	function addPopupValues(data) {
-		if (data.object === 'name') {
-			jQuery('#application').val(data.values[0].name);
-		}
-		else if (data.object === 'linktrigger') {
+		if (data.object === 'linktrigger') {
 			ZABBIX.apps.map.object.linkForm.addNewTriggers(data.values);
 		}
 	}
