@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -73,7 +73,11 @@ $filter_column = (new CFormList())
 		]))->setWidth(ZBX_TEXTAREA_FILTER_STANDARD_WIDTH)
 	)
 	->addRow(new CLabel(_('Severity')),
-		(new CSeverityCheckBoxList('severities'))->setChecked($data['filter']['severities'])
+		(new CCheckBoxList('severities'))
+			->setOptions(CSeverityHelper::getSeverities())
+			->setChecked($data['filter']['severities'])
+			->setColumns(3)
+			->setVertical(true)
 	);
 
 $filterForm
