@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -561,13 +561,23 @@ class CDashboard extends CBaseComponent {
 
 				this._selectDashboardPage(dashboard_page, {is_async: true});
 			})
-			.catch((error) => {
+			.catch((exception) => {
 				clearMessages();
 
-				addMessage((typeof error === 'object' && 'html_string' in error)
-					? error.html_string
-					: makeMessageBox('bad', [], t('Failed to paste dashboard page.'), true, false)
-				);
+				let title;
+				let messages = [];
+
+				if (typeof exception === 'object' && 'error' in exception) {
+					title = exception.error.title;
+					messages = exception.error.messages;
+				}
+				else {
+					title = t('Failed to paste dashboard page.');
+				}
+
+				const message_box = makeMessageBox('bad', messages, title);
+
+				addMessage(message_box);
 			})
 			.finally(() => this._deleteBusyCondition(busy_condition))
 	}
@@ -653,13 +663,24 @@ class CDashboard extends CBaseComponent {
 					unique_id: this._createUniqueId()
 				});
 			})
-			.catch((error) => {
+			.catch((exception) => {
+				dashboard_page.deleteWidget(paste_placeholder_widget);
+
 				clearMessages();
 
-				addMessage((typeof error === 'object' && 'html_string' in error)
-					? error.html_string
-					: makeMessageBox('bad', [], t('Failed to paste widget.'), true, false)
-				);
+				let title, messages;
+
+				if (typeof exception === 'object' && 'error' in exception) {
+					title = exception.error.title;
+					messages = exception.error.messages;
+				}
+				else {
+					title = t('Failed to paste widget.');
+				}
+
+				const message_box = makeMessageBox('bad', messages, title);
+
+				addMessage(message_box);
 			})
 			.finally(() => this._deleteBusyCondition(busy_condition));
 	}
@@ -680,15 +701,13 @@ class CDashboard extends CBaseComponent {
 
 		return fetch(curl.getUrl(), {
 			method: 'POST',
-			headers: {
-				'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8'
-			},
-			body: urlEncodeData({widgets: request_widgets_data})
+			headers: {'Content-Type': 'application/json'},
+			body: JSON.stringify({widgets: request_widgets_data})
 		})
 			.then((response) => response.json())
 			.then((response) => {
-				if ('errors' in response) {
-					throw {html_string: response.errors};
+				if ('error' in response) {
+					throw {error: response.error};
 				}
 
 				return response;
@@ -936,7 +955,10 @@ class CDashboard extends CBaseComponent {
 			auto_start: this._data.auto_start
 		};
 
-		PopUp('dashboard.properties.edit', properties, 'dashboard_properties', document.activeElement);
+		PopUp('dashboard.properties.edit', properties, {
+			dialogueid: 'dashboard_properties',
+			dialogue_class: 'modal-popup-generic'
+		});
 	}
 
 	applyProperties() {
@@ -954,16 +976,24 @@ class CDashboard extends CBaseComponent {
 
 				this.fire(DASHBOARD_EVENT_APPLY_PROPERTIES);
 			})
-			.catch((error) => {
-				for (const el of form.parentNode.children) {
-					if (el.matches('.msg-good, .msg-bad, .msg-warning')) {
-						el.parentNode.removeChild(el);
+			.catch((exception) => {
+				for (const element of form.parentNode.children) {
+					if (element.matches('.msg-good, .msg-bad, .msg-warning')) {
+						element.parentNode.removeChild(element);
 					}
 				}
 
-				const message_box = (typeof error === 'object' && 'html_string' in error)
-					? new DOMParser().parseFromString(error.html_string, 'text/html').body.firstElementChild
-					: makeMessageBox('bad', [], t('Failed to update dashboard properties.'), true, false)[0];
+				let title, messages;
+
+				if (typeof exception === 'object' && 'error' in exception) {
+					title = exception.error.title;
+					messages = exception.error.messages;
+				}
+				else {
+					messages = [t('Failed to update dashboard properties.')];
+				}
+
+				const message_box = makeMessageBox('bad', messages, title)[0];
 
 				form.parentNode.insertBefore(message_box, form);
 			})
@@ -977,21 +1007,19 @@ class CDashboard extends CBaseComponent {
 		properties.template = this._data.templateid !== null ? 1 : undefined;
 		properties.name = properties.name.trim();
 
-		const curl = new Curl('zabbix.php', false);
+		const curl = new Curl('zabbix.php');
 
 		curl.setArgument('action', 'dashboard.properties.check');
 
 		return fetch(curl.getUrl(), {
 			method: 'POST',
-			headers: {
-				'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8'
-			},
-			body: urlEncodeData(properties)
+			headers: {'Content-Type': 'application/json'},
+			body: JSON.stringify(properties)
 		})
 			.then((response) => response.json())
 			.then((response) => {
-				if ('errors' in response) {
-					throw {html_string: response.errors};
+				if ('error' in response) {
+					throw {error: response.error};
 				}
 
 				this._data.name = properties.name;
@@ -1004,7 +1032,10 @@ class CDashboard extends CBaseComponent {
 	editDashboardPageProperties(properties = {}) {
 		properties.dashboard_display_period = this._data.display_period;
 
-		PopUp('dashboard.page.properties.edit', properties, 'dashboard_page_properties', document.activeElement);
+		PopUp('dashboard.page.properties.edit', properties, {
+			dialogueid: 'dashboard_page_properties',
+			dialogue_class: 'modal-popup-generic'
+		});
 	}
 
 	applyDashboardPageProperties() {
@@ -1021,16 +1052,24 @@ class CDashboard extends CBaseComponent {
 			.then(() => {
 				overlayDialogueDestroy(overlay.dialogueid);
 			})
-			.catch((error) => {
-				for (const el of form.parentNode.children) {
-					if (el.matches('.msg-good, .msg-bad, .msg-warning')) {
-						el.parentNode.removeChild(el);
+			.catch((exception) => {
+				for (const element of form.parentNode.children) {
+					if (element.matches('.msg-good, .msg-bad, .msg-warning')) {
+						element.parentNode.removeChild(element);
 					}
 				}
 
-				const message_box = (typeof error === 'object' && 'html_string' in error)
-					? new DOMParser().parseFromString(error.html_string, 'text/html').body.firstElementChild
-					: makeMessageBox('bad', [], t('Failed to update dashboard page properties.'), true, false)[0];
+				let title, messages;
+
+				if (typeof exception === 'object' && 'error' in exception) {
+					title = exception.error.title;
+					messages = exception.error.messages;
+				}
+				else {
+					messages = [t('Failed to update dashboard page properties.')];
+				}
+
+				const message_box = makeMessageBox('bad', messages, title)[0];
 
 				form.parentNode.insertBefore(message_box, form);
 			})
@@ -1043,21 +1082,19 @@ class CDashboard extends CBaseComponent {
 	_promiseApplyDashboardPageProperties(properties, data) {
 		properties.name = properties.name.trim();
 
-		const curl = new Curl('zabbix.php', false);
+		const curl = new Curl('zabbix.php');
 
 		curl.setArgument('action', 'dashboard.page.properties.check');
 
 		return fetch(curl.getUrl(), {
 			method: 'POST',
-			headers: {
-				'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8'
-			},
-			body: urlEncodeData(properties)
+			headers: {'Content-Type': 'application/json'},
+			body: JSON.stringify(properties)
 		})
 			.then((response) => response.json())
 			.then((response) => {
-				if ('errors' in response) {
-					throw {html_string: response.errors};
+				if ('error' in response) {
+					throw {error: response.error};
 				}
 
 				if (data.unique_id !== null) {
@@ -1093,17 +1130,14 @@ class CDashboard extends CBaseComponent {
 		const overlay = PopUp('dashboard.widget.edit', {
 			templateid: this._data.templateid ?? undefined,
 			...properties
-		}, 'widget_properties', document.activeElement);
+		}, {
+			dialogueid: 'widget_properties',
+			dialogue_class: 'modal-widget-configuration'
+		});
 
 		overlay.xhr.then(() => {
 			const form = overlay.$dialogue.$body[0].querySelector('form');
 			const original_properties = overlay.data.original_properties;
-			const dialogue_stick_to_top = this._widget_defaults[original_properties.type].dialogue_stick_to_top;
-
-			if (dialogue_stick_to_top !== overlay.$dialogue[0].classList.contains('sticked-to-top')) {
-				overlay.$dialogue[0].classList.toggle('sticked-to-top', dialogue_stick_to_top);
-				overlay.centerDialog();
-			}
 
 			if (original_properties.unique_id === null) {
 				this._new_widget_dashboard_page = this._selected_dashboard_page;
@@ -1140,8 +1174,8 @@ class CDashboard extends CBaseComponent {
 						}
 					}
 
-					const message_box = makeMessageBox('warning',
-						t('Cannot add widget: not enough free space on the dashboard.'), null, false
+					const message_box = makeMessageBox('warning', [],
+						t('Cannot add widget: not enough free space on the dashboard.')
 					)[0];
 
 					form.parentNode.insertBefore(message_box, form);
@@ -1159,7 +1193,10 @@ class CDashboard extends CBaseComponent {
 
 		if (!this._is_edit_widget_properties_cancel_subscribed) {
 			this._is_edit_widget_properties_cancel_subscribed = true;
-			$.subscribe('overlay.close', this._events.editWidgetPropertiesCancel);
+
+			overlay.$dialogue[0].addEventListener('overlay.close', this._events.editWidgetPropertiesCancel,
+				{once: true}
+			);
 		}
 	}
 
@@ -1268,16 +1305,24 @@ class CDashboard extends CBaseComponent {
 						});
 				}
 			})
-			.catch((error) => {
-				for (const el of form.parentNode.children) {
-					if (el.matches('.msg-good, .msg-bad, .msg-warning')) {
-						el.parentNode.removeChild(el);
+			.catch((exception) => {
+				for (const element of form.parentNode.children) {
+					if (element.matches('.msg-good, .msg-bad, .msg-warning')) {
+						element.parentNode.removeChild(element);
 					}
 				}
 
-				const message_box = (typeof error === 'object' && 'html_string' in error)
-					? new DOMParser().parseFromString(error.html_string, 'text/html').body.firstElementChild
-					: makeMessageBox('bad', [], t('Failed to update widget properties.'), true, false)[0];
+				let title, messages;
+
+				if (typeof exception === 'object' && 'error' in exception) {
+					title = exception.error.title;
+					messages = exception.error.messages;
+				}
+				else {
+					messages = [t('Failed to update widget properties.')];
+				}
+
+				const message_box = makeMessageBox('bad', messages, title)[0];
 
 				form.parentNode.insertBefore(message_box, form);
 			})
@@ -1296,15 +1341,13 @@ class CDashboard extends CBaseComponent {
 
 		return fetch(curl.getUrl(), {
 			method: 'POST',
-			headers: {
-				'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8'
-			},
-			body: urlEncodeData({templateid, type, name, view_mode, fields: fields_str})
+			headers: {'Content-Type': 'application/json'},
+			body: JSON.stringify({templateid, type, name, view_mode, fields: fields_str})
 		})
 			.then((response) => response.json())
 			.then((response) => {
-				if ('errors' in response) {
-					throw {html_string: response.errors};
+				if ('error' in response) {
+					throw {error: response.error};
 				}
 			});
 	}
@@ -1318,14 +1361,16 @@ class CDashboard extends CBaseComponent {
 
 		return fetch(curl.getUrl(), {
 			method: 'POST',
-			headers: {
-				'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8'
-			},
-			body: urlEncodeData({templateid, type, view_mode, fields: fields_str})
+			headers: {'Content-Type': 'application/json'},
+			body: JSON.stringify({templateid, type, view_mode, fields: fields_str})
 		})
 			.then((response) => response.json())
 			.then((response) => {
-				return typeof response.configuration === 'object' ? response.configuration : {};
+				if ('error' in response) {
+					throw {error: response.error};
+				}
+
+				return response.configuration;
 			});
 	}
 
@@ -1391,7 +1436,7 @@ class CDashboard extends CBaseComponent {
 		this._warning_message_box = makeMessageBox('warning', [], sprintf(
 			t('Cannot add dashboard page: maximum number of %1$d dashboard pages has been added.'),
 			this._max_dashboard_pages
-		), true, false);
+		));
 
 		addMessage(this._warning_message_box);
 	}
@@ -1399,8 +1444,8 @@ class CDashboard extends CBaseComponent {
 	_warnDashboardPageExhausted() {
 		this._clearWarnings();
 
-		this._warning_message_box = makeMessageBox(
-			'warning', [], t('Cannot add widget: not enough free space on the dashboard.'), true, false
+		this._warning_message_box = makeMessageBox('warning', [],
+			t('Cannot add widget: not enough free space on the dashboard.')
 		);
 
 		addMessage(this._warning_message_box);
@@ -1900,13 +1945,10 @@ class CDashboard extends CBaseComponent {
 				}
 			},
 
-			editWidgetPropertiesCancel: (e, data) => {
-				if (data.dialogueid === 'widget_properties') {
-					this._cancelEditingWidgetProperties();
+			editWidgetPropertiesCancel: () => {
+				this._cancelEditingWidgetProperties();
 
-					$.unsubscribe('overlay.close', this._events.editWidgetPropertiesCancel);
-					this._is_edit_widget_properties_cancel_subscribed = false;
-				}
+				this._is_edit_widget_properties_cancel_subscribed = false;
 			}
 		};
 	}
