@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -120,10 +120,10 @@ class CWidget extends CBaseComponent {
 		this._update_abort_controller = null;
 		this._is_updating_paused = false;
 		this._update_retry_sec = 3;
-		this._preloader_timeout = null;
-		this._preloader_timeout_sec = 10;
 		this._show_preloader_asap = true;
 		this._resizable_handles = [];
+
+		this._hide_preloader_animation_frame = null;
 	}
 
 	// Logical state control methods.
@@ -388,11 +388,18 @@ class CWidget extends CBaseComponent {
 
 			fetch(curl.getUrl(), {
 				method: 'POST',
-				headers: {
-					'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8'
-				},
-				body: urlEncodeData({widgetid: this._widgetid, rf_rate})
-			});
+				headers: {'Content-Type': 'application/json'},
+				body: JSON.stringify({widgetid: this._widgetid, rf_rate})
+			})
+				.then((response) => response.json())
+				.then((response) => {
+					if ('error' in response) {
+						throw {error: response.error};
+					}
+				})
+				.catch((exception) => {
+					console.log('Could not update widget refresh rate:', exception);
+				});
 		}
 	}
 
@@ -516,7 +523,7 @@ class CWidget extends CBaseComponent {
 		if (delay_sec > 0) {
 			this._update_timeout_id = setTimeout(() => {
 				this._update_timeout_id = null;
-				this._startUpdating(0, {do_update_once: do_update_once});
+				this._startUpdating(0, {do_update_once});
 			}, delay_sec * 1000);
 		}
 		else {
@@ -556,7 +563,7 @@ class CWidget extends CBaseComponent {
 
 	_update(do_update_once) {
 		if (this._update_abort_controller !== null || this._is_updating_paused || this.isUserInteracting()) {
-			this._startUpdating(1, {do_update_once: do_update_once});
+			this._startUpdating(1, {do_update_once});
 
 			return;
 		}
@@ -577,14 +584,14 @@ class CWidget extends CBaseComponent {
 
 		new Promise((resolve) => resolve(this._promiseUpdate()))
 			.then(() => this._hidePreloader())
-			.catch((error) => {
-				console.log('Could not update widget:', error);
+			.catch((exception) => {
+				console.log('Could not update widget:', exception);
 
 				if (this._update_abort_controller.signal.aborted) {
 					this._hidePreloader();
 				}
 				else {
-					this._startUpdating(this._update_retry_sec, {do_update_once: do_update_once});
+					this._startUpdating(this._update_retry_sec, {do_update_once});
 				}
 			})
 			.finally(() => {
@@ -601,14 +608,20 @@ class CWidget extends CBaseComponent {
 
 		return fetch(curl.getUrl(), {
 			method: 'POST',
-			headers: {
-				'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8'
-			},
-			body: urlEncodeData(this._getUpdateRequestData()),
+			headers: {'Content-Type': 'application/json'},
+			body: JSON.stringify(this._getUpdateRequestData()),
 			signal: this._update_abort_controller.signal
 		})
 			.then((response) => response.json())
-			.then((response) => this._processUpdateResponse(response));
+			.then((response) => {
+				if ('error' in response) {
+					this._processUpdateErrorResponse(response.error);
+
+					return;
+				}
+
+				this._processUpdateResponse(response);
+			});
 	}
 
 	_getUpdateRequestData() {
@@ -637,6 +650,10 @@ class CWidget extends CBaseComponent {
 		});
 	}
 
+	_processUpdateErrorResponse(error) {
+		this._setErrorContents({error});
+	}
+
 	// Widget view methods.
 
 	getView() {
@@ -736,10 +753,14 @@ class CWidget extends CBaseComponent {
 		this._content_body.innerHTML = '';
 
 		if (messages !== undefined) {
-			this._content_body.insertAdjacentHTML('beforeend', messages);
+			const message_box = makeMessageBox('bad', messages)[0];
+
+			this._content_body.appendChild(message_box);
 		}
 
-		this._content_body.insertAdjacentHTML('beforeend', body);
+		if (body !== undefined) {
+			this._content_body.insertAdjacentHTML('beforeend', body);
+		}
 
 		if (debug !== undefined) {
 			this._content_body.insertAdjacentHTML('beforeend', debug);
@@ -752,6 +773,17 @@ class CWidget extends CBaseComponent {
 		}
 	}
 
+	_setErrorContents({error}) {
+		this._setHeaderName(this._defaults.name);
+
+		const message_box = makeMessageBox('bad', error.messages, error.title)[0];
+
+		this._content_body.innerHTML = '';
+		this._content_body.appendChild(message_box);
+
+		this._removeInfoButtons();
+	}
+
 	_addInfoButtons(buttons) {
 		buttons.reverse();
 
@@ -786,38 +818,39 @@ class CWidget extends CBaseComponent {
 	}
 
 	_showPreloader() {
-		if (this._preloader_timeout !== null) {
-			clearTimeout(this._preloader_timeout);
-			this._preloader_timeout = null;
+		// Fixed Safari 16 bug: removing preloader classes on animation frame to ensure removal of icons.
+
+		if (this._hide_preloader_animation_frame !== null) {
+			cancelAnimationFrame(this._hide_preloader_animation_frame);
+			this._hide_preloader_animation_frame = null;
 		}
 
 		this._content_body.classList.add('is-loading');
+		this._content_body.classList.remove('is-loading-fadein', 'delayed-15s');
 	}
 
 	_hidePreloader() {
-		if (this._preloader_timeout !== null) {
-			clearTimeout(this._preloader_timeout);
-			this._preloader_timeout = null;
+		// Fixed Safari 16 bug: removing preloader classes on animation frame to ensure removal of icons.
+
+		if (this._hide_preloader_animation_frame !== null) {
+			return;
 		}
 
-		this._content_body.classList.remove('is-loading');
+		this._hide_preloader_animation_frame = requestAnimationFrame(() => {
+			this._content_body.classList.remove('is-loading', 'is-loading-fadein', 'delayed-15s');
+			this._hide_preloader_animation_frame = null;
+		});
 	}
 
-	_schedulePreloader(delay_sec = this._preloader_timeout_sec) {
-		if (this._preloader_timeout !== null) {
-			return;
+	_schedulePreloader() {
+		// Fixed Safari 16 bug: removing preloader classes on animation frame to ensure removal of icons.
+
+		if (this._hide_preloader_animation_frame !== null) {
+			cancelAnimationFrame(this._hide_preloader_animation_frame);
+			this._hide_preloader_animation_frame = null;
 		}
 
-		const is_showing_preloader = this._content_body.classList.contains('is-loading');
-
-		if (is_showing_preloader) {
-			return;
-		}
-
-		this._preloader_timeout = setTimeout(() => {
-			this._preloader_timeout = null;
-			this._showPreloader();
-		}, delay_sec * 1000);
+		this._content_body.classList.add('is-loading', 'is-loading-fadein', 'delayed-15s');
 	}
 
 	_makeView() {
